package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.28.1 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.28.1) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@(!`0````````````,``@$!````^"8```````!``````````-##````
M`````P```$``.``)`$``&@`9``8````$````0`````````!``````````$``
M````````^`$```````#X`0````````@``````````P````0````X`@``````
M`#@"````````.`(````````/``````````\``````````0`````````!````
M!0```````````````````````````````````%BD````````6*0`````````
M0`````````$````&````H+,```````"@\P```````*#S````````(`\`````
M``!0'P````````!``````````@````8```#`O0```````,#]````````P/T`
M``````!``@```````$`"````````"``````````$````!````$@"````````
M2`(```````!(`@```````$0`````````1``````````$`````````%#E=&0$
M````?*,```````!\HP```````'RC````````W`````````#<``````````0`
M````````4>5T9`8`````````````````````````````````````````````
M````````````$`````````!2Y71D!````*"S````````H/,```````"@\P``
M`````&`,````````8`P````````!`````````"]L:6(V-"]L9"YS;RXQ```$
M````$`````$```!'3E4```````0````/``````````0````4`````P```$=.
M50`=MJ[Y[O#STY8L5C&7AKS5+N^]4@````!A````:```````````````````
M``L``````````````#<``````````````"D```!$`````````!8````M````
M```````````[````5````%4```!&````8````&8````Y````-```````````
M````'P```%T```!%``````````````!0````7@```$,``````````````&<`
M```R`````````%$`````````%0`````````@````80```%,```!.````````
M`$````!C`````````#@````C``````````````!<````3P```$(```!,````
M```````````9`````````$D`````````````````````````-0```#H````H
M````'@```%\````F``````````````!B````(@```$$```!'````5P```#8`
M```_`````````$H```````````````````!D````6`````````!+````6@``
M`$@```!-````,`````<`````````````````````````````````````````
M````````````````````````````````"0````````````````````T`````
M````````````````````````````````````````````````````````````
M```2```````````````;````60```````````````````!0````*````````
M`!T`````````*@````````````````````\````K``````````````!E````
M%P``````````````#```````````````&@`````````8`````````#,````Q
M`````````%(````]````6P`````````\````+@```"P`````````)0```!,`
M````````$0`````````G`````````%8````.```````````````D````````
M```````<````````````````````(0`````````^````+P```!``````````
M``````````````````````@````````````````````1````4@````(````'
M````FI6```EA!$@(CA1-BH0`Z`````!2````50```%@```!9`````````%\`
M``!@````8@```&,``````````````&4```!F````9P``````````````;L7?
M'\[>1RUK?YI\+L6;MM1DU'PA_^0.V7%8'.)'Q@&R`8MOK$OCP,+E/RRZXY)\
M^Z%L8&>OS&9"1=7LB0=PTPT4XIXR8MOMV\WCGG^IG)OAIP(*H^#[20``````
M`````````````````````````````````````P`-`*`D````````````````
M`````````P`.`#AC`````````````````````````P`0`*#S````````````
M`````````````P`4`````0```````````````````````P`6`+@"`0``````
M`````````````````P`7`,`"`0````````````````#[`0``$@``````````
M``````````````!R`P``$0````````````````````````#]````$@``````
M``````````````````!R`@``$@`````````````````````````@`@``$@``
M``````````````````````"$````$@````````````````````````#R````
M$0````````````````````````"$`0``$@````````````````````````#;
M`@``$@````````````````````````!Y`@``$@``````````````````````
M``";`0``$@````````````````````````#_`@``$@``````````````````
M```````3`0``$@````````````````````````!0`P``$0``````````````
M```````````N`P``$@`````````````````````````;`@``$@``````````
M``````````````#S`0``$@````````````````````````!$`0``$@``````
M``````````````````"E````$@`````````````````````````T`0``$@``
M```````````````````````F`0``$@````````````````````````".`@``
M$@````````````````````````#2`0``$@````````````````````````"'
M`@``$@````````````````````````!"`@``$@``````````````````````
M```,`@``$@````````````````````````!8`P``$@``````````````````
M```````1````(`````````````````````````#B`@``$@``````````````
M``````````!7`@``$@````````````````````````"B`0``$@``````````
M```````````````M````(``````````````````````````H`@``$@``````
M``````````````````#*`@``$@````````````````````````!/`P``(0``
M``````````````````````!'````$@````````````````````````"B`@``
M$@````````````````````````!.`P``$0````````````````````````!D
M`@``$@````````````````````````!T`0``$@``````````````````````
M```U`P``$@````````````````````````!D````$@``````````````````
M``````#A````$@````````````````````````!U````$@``````````````
M```````````\`P``$@````````````````````````#%````$@``````````
M```````````````"`0``$@`````````````````````````F`P``$@``````
M``````````````````!F`0``$@````````````````````````#X`@``$@``
M``````````````````````!)`@``$@````````````````````````#M`0``
M$@````````````````````````!8`0``$@````````````````````````!K
M`@``$@````````````````````````!=`@``$@``````````````````````
M``#4`@``$0`````````````````````````'`0``$@``````````````````
M```````)`P``(@````````````````````````"0````$@``````````````
M``````````!/`@``$@````````````````````````"``@``$@``````````
M``````````````"/`0``$@````````````````````````"W`@``$@``````
M``````````````````"4`@``$@`````````````````````````8!```$@``
M``````````````````````#F`0``$@````````````````````````#4````
M$0`````````````````````````8`P``$@````````````````````````!-
M`0``$@````````````````````````!5````$@``````````````````````
M``#"`@``$@````````````````````````#K`@``$@``````````````````
M```````Q`@``$@````````````````````````"I`@``$@``````````````
M``````````"S````$@`````````````````````````A!```$@`-`/AA````
M````F`````````!E!```$@`-`$Q0````````O`T```````!)`P``$@`-`*`D
M````````5`(```````"2`P``$@`-`&1)````````!`````````#``P``$@`-
M``A>````````\`,```````"+!```$@`-`&A)````````/`(```````!4!```
M$``7`,`"`0````````````````"C`P``$@`-`*1+````````,`````````#6
M`P``$@`-`+1.````````E``````````M!```$0`.`#AC````````!```````
M```\!```$@`-`,!'````````/`````````!@!```$``7`/`2`0``````````
M``````!Y!```$@`-`&Q/````````X`````````#Z`P``$@`-`-1+````````
M$`$```````!R!```$``6`,`"`0````````````````"8!```$0`4`#@``0``
M````"`````````"P`P``$@`-`"!C````````!`````````!9!```$@`-`/@F
M````````A`````````!$!```$@`-`)!B````````D``````````&!```$@`-
M`$A/````````)`````````#D`P``$@`-`%1(````````$`$```````"B!```
M$@`-`.1,````````T`$`````````;&EB<&5R;"YS;RXU+C(X`%])5$U?9&5R
M96=I<W1E<E1-0VQO;F5486)L90!?251-7W)E9VES=&5R5$U#;&]N951A8FQE
M`%!E<FQ?<WES7W1E<FT`4&5R;%]S>7-?:6YI=#,`4&5R;%]A=&9O<FM?;&]C
M:P!P97)L7V-O;G-T<G5C=`!097)L7V=E=%]S=@!097)L7V-R;V%K7VYO8V]N
M=&5X=`!097)L7V%V7W-H:69T`%!E<FQ?<W9?,G!V7V9L86=S`%!E<FQ?<W9?
M<V5T<'9N`%!,7V1O7W5N9'5M<`!097)L7VYE=UA37V9L86=S`%!,7W1H<E]K
M97D`<&5R;%]F<F5E`%!E<FQ?;6=?<V5T`%!E<FQ?871F;W)K7W5N;&]C:P!0
M97)L7W-V7W-E='!V`%!E<FQ?9W9?9F5T8VAP=@!P97)L7W)U;@!097)L7VYE
M=UA3`'!E<FQ?9&5S=')U8W0`4&5R;%]A=E]F971C:`!B;V]T7T1Y;F%,;V%D
M97(`<&5R;%]P87)S90!097)L7W-A9F5S>7-M86QL;V,`<&5R;%]A;&QO8P!L
M:6)D;"YS;RXR`&QI8FTN<V\N-@!L:6)P=&AR96%D+G-O+C``<'1H<F5A9%]G
M971S<&5C:69I8P!O<&5N-C0`8VQO<V4`;'-E96LV-`!?7V5R<FYO7VQO8V%T
M:6]N`')E860`;&EB8RYS;RXV`&5X:70`<W1R;F-M<`!C;&]S961I<@!?7W-T
M86-K7V-H:U]F86EL`'5N;&EN:P!M:V1I<@!R96%L;&]C`&%B;W)T`&UE;6-H
M<@!G971P:60`<W1R9'5P`'-T<G1O:P!S=')L96X`;65M<V5T`'-T<G-T<@!R
M;61I<@!?7V9P<FEN=&9?8VAK`&UE;6-P>0!?7W-T<FYC<'E?8VAK`%]?;'AS
M=&%T-C0`;W!E;F1I<@!?7WAS=&%T-C0`<W1D97)R`&=E='5I9`!R96%D;&EN
M:P!?7VUE;6-P>5]C:&L`<W1R8VAR`')E861D:7(V-`!?7V-X85]F:6YA;&EZ
M90!?7W-P<FEN=&9?8VAK`&UE;6UO=F4`86-C97-S`'-T<F-M<`!?7VQI8F-?
M<W1A<G1?;6%I;@!?7V5N=FER;VX`7U]R96=I<W1E<E]A=&9O<FL`;&0N<V\N
M,0!?7W-T86-K7V-H:U]G=6%R9`!L:6)C<GEP="YS;RXQ`'!A<E]C=7)R96YT
M7V5X96,`<&%R7V)A<V5N86UE`%]?;&EB8U]C<W5?9FEN:0!84U]);G1E<FYA
M;'-?4$%27T)/3U0`<&%R7V5N=E]C;&5A;@!P87)?8W5R<F5N=%]E>&5C7W!R
M;V,`<&%R7V1I<FYA;64`9V5T7W5S97)N86UE7V9R;VU?9V5T<'=U:60`<&%R
M7V-L96%N=7``7TE/7W-T9&EN7W5S960`>'-?:6YI=`!?7VQI8F-?8W-U7VEN
M:70`7U]B<W-?<W1A<G0`7V5N9`!P87)?;6MT;7!D:7(`7V5D871A`'!A<E]S
M971U<%]L:6)P871H`'!A<E]F:6YD<')O9P!M>5]P87)?<&P`<&%R7VEN:71?
M96YV`$=,24)#7S(N,C<`1TQ)0D-?,BXR`$=,24)#7S(N,```````````````
M``````(``P````0`!``````````$``0`!``$````!``$``0`!0``````````
M``0``@`$``0``@`$````!``$```````$``0`!`````0`!``$````!```````
M```$````!``$````!``$``(````$``0`!`````0````$``0````$``0`!``%
M````!```````!``$``0`!`````$``0`!``$``0`!``$``0`!``$``0`!``$`
M`0`!``$``0`!``$``0`!``$````!``$`$0(``!`````@````AY&6!@``!`"O
M!`````````$``0!J`P``$````"````"'D98&```#`*\$`````````0`"`,(!
M```0`````````!)I:0T```4`N@0``!`````0:6D-```"`,0$````````L/T`
M```````#`````````(0H````````N/T````````#`````````!PH````````
M```!```````#`````````*!D````````"``!```````#`````````#!F````
M````$``!```````#`````````#AF````````&``!```````#`````````$!F
M````````(``!```````#`````````$AF````````.``!```````#````````
M`!!G````````0`(!```````#`````````"!C````````D`(!```````#````
M`````)!B````````L`(!```````#`````````*`D````````N`(!```````#
M`````````+@"`0``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````.`(!```````"````"```````````````2`(!```````"````
M#0``````````````4`(!```````"````$P``````````````6`(!```````"
M````%```````````````8`(!```````"````(@``````````````:`(!````
M```"````)```````````````<`(!```````"````)@``````````````>`(!
M```````"````+@``````````````@`(!```````"````,```````````````
MB`(!```````"````,P``````````````F`(!```````"````/@``````````
M````H`(!```````"````0```````````````J`(!```````"````20``````
M````````4``!```````%````!P``````````````6``!```````%````"0``
M````````````8``!```````%````"@``````````````:``!```````%````
M"P``````````````<``!```````%````#```````````````>``!```````%
M````#@``````````````@``!```````%````#P``````````````B``!````
M```%````$```````````````D``!```````%````$0``````````````F``!
M```````%````$@``````````````H``!```````%````%0``````````````
MJ``!```````%````%@``````````````L``!```````%````%P``````````
M````N``!```````%````&```````````````P``!```````%````&0``````
M````````R``!```````%````&@``````````````T``!```````%````&P``
M````````````V``!```````%````'```````````````X``!```````%````
M'0``````````````Z``!```````%````'@``````````````\``!```````%
M````'P``````````````^``!```````%````(`````````````````$!````
M```%````(0``````````````"`$!```````%````(P``````````````$`$!
M```````%````)0``````````````&`$!```````%````)P``````````````
M(`$!```````%````*```````````````*`$!```````%````*@``````````
M````,`$!```````%````*P``````````````.`$!```````%````+0``````
M````````0`$!```````%````+P``````````````2`$!```````%````,0``
M````````````4`$!```````%````,@``````````````6`$!```````%````
M-```````````````8`$!```````%````-0``````````````:`$!```````%
M````-@``````````````<`$!```````%````-P``````````````>`$!````
M```%````.```````````````@`$!```````%````.0``````````````B`$!
M```````%````.@``````````````D`$!```````%````.P``````````````
MF`$!```````%````/```````````````H`$!```````%````/0``````````
M````J`$!```````%````/P``````````````L`$!```````%````00``````
M````````N`$!```````%````0@``````````````P`$!```````%````0P``
M````````````R`$!```````%````1```````````````T`$!```````%````
M10``````````````V`$!```````%````1@``````````````X`$!```````%
M````1P``````````````Z`$!```````%````2```````````````\`$!````
M```%````2@``````````````^`$!```````%````2P````````````````(!
M```````%````3```````````````"`(!```````%````30``````````````
M$`(!```````%````3@``````````````&`(!```````%````3P``````````
M````(`(!```````%````4```````````````*`(!```````%````40``````
M``````````````````#.`0`<K;T1`,\!_BBM8?\"S`'^`JT%10",(<`HX`$`
M3,\!`!SOP?TH#0``'.`!`$S/`0`<[Z']*`T``!S@`0!,SP$`'.^!_2@-```<
MX`$`3,\!`!SO8?TH#0``'.`!`$S/`0`<[T']*`T``!S@`0!,SP$`'.\A_2@-
M```<X`$`3,\!`!SO`?TH#0``'.`!`$S/`0`<[^'\*`T``!S@`0!,SP$`'._!
M_"@-```<X`$`3,\!`!SOH?PH#0``'.`!`$S/`0`<[X'\*`T``!S@`0!,SP$`
M'.]A_"@-```<X`$`3,\!`!SO0?PH#0``'.`!`$S/`0`<[R'\*`T``!S@`0!,
MSP$`'.\!_"@-```<X`$`3,\!`!SOX?LH#0``'.`!`$S/`0`<[\'[*`T``!S@
M`0!,SP$`'.^A^R@-```<X`$`3,\!`!SO@?LH#0``'.`!`$S/`0`<[V'[*`T`
M`!S@`0!,SP$`'.]!^R@-```<X`$`3,\!`!SO(?LH#0``'.`!`$S/`0`<[P'[
M*`T``!S@`0!,SP$`'._A^B@-```<X`$`3,\!`!SOP?HH#0``'.`!`$S/`0`<
M[Z'Z*`T``!S@`0!,SP$`'.^!^B@-```<X`$`3,\!`!SO8?HH#0``'.`!`$S/
M`0`<[T'Z*`T``!S@`0!,SP$`'.\A^B@-```<X`$`3,\!`!SO`?HH#0``'.`!
M`$S/`0`<[^'Y*`T``!S@`0!,SP$`'._!^2@-```<X`$`3,\!`!SOH?DH#0``
M'.`!`$S/`0`<[X'Y*`T``!S@`0!,SP$`'.]A^2@-```<X`$`3,\!`!SO0?DH
M#0``'.`!`$S/`0`<[R'Y*`T``!S@`0!,SP$`'.\!^2@-```<X`$`3,\!`!SO
MX?@H#0``'.`!`$S/`0`<[\'X*`T``!S@`0!,SP$`'.^A^"@-```<X`$`3,\!
M`!SO@?@H#0``'.`!`$S/`0`<[V'X*`T``!S@`0!,SP$`'.]!^"@-```<X`$`
M3,\!`!SO(?@H#0``'.`!`$S/`0`<[P'X*`T``!S@`0!,SP$`'._A]R@-```<
MX`$`3,\!`!SOP?<H#0``'.`!`$S/`0`<[Z'W*`T``!S@`0!,SP$`'.^!]R@-
M```<X`$`3,\!`!SO8?<H#0``'.`!`$S/`0`<[T'W*`T``!S@`0!,SP$`'.\A
M]R@-```<X`$`3,\!`!SO`?<H#0``'.`!`$S/`0`<[^'V*`T``!S@`0!,SP$`
M'._!]B@-```<X`$`3,\!`!SOH?8H#0``'.`!`$S/`0`<[X'V*`T``!S@`0!,
MSP$`'.]A]B@-```<X`$`3&.`_@)X(,$IV`$`'!A#]B@,`P`F94#`*68@P"ED
M'``E9B#``F5`P`)D<,`";*#`*6%@P2EW0,$I>0#!*7K@P"E[P,`I_U__5\8!
M`!S&H/4HQ0`5`,0!`!R$,/8H`"@^5,P!`!R,H?8HC`$`*H!A`4#W`0`<]V+W
M`MD!`!PYP_0H)`,`)/_?_%>,2!(JC0`5`"0#`"2,"8`#K$D2*?_'_%>-2!(J
M;!P`)*T%@`.,%8`"C4@2*80-00#_>_Y7;$#`*,T!`!RM8>L"K0$`)HX!`"9F
M'``DC4#`*8X``">-```<K3'&`HX``!S.\<4"[P$`'.\1]0*.(,`IC6#`*0X0
M@`+M`0`<K>'T`JX!`"7D`0`G#02``H<`%0#2$(`"IBT`9(PAP`(-%(`"40(5
M`)`!`":O'2T`K@6``O#A_RG-`14`C"'``B[J_U_D`@`F4AXM``@`%0#&#(`"
M10``'*40R`)`XO\I_R_[5YD`%0"`F`!`Y`(`)GJ0P`+_2_U710,5`(0``!R$
M0/@"`'095("(`$#D`@`F_[_Z5_];_%=MH,`H#`,`)B0#%0"LH0!<86#!*'=`
MP2AX(,$H>0#!*'K@P"A[P,`H8X#!`B```$S_]_M7]P$`'/?B\0+D`@`G@'``
M0/]C_%?9`0`<.1/O*"0#`"3_<_M7+```%(2P$`"`I"@I_X/^4^0"`";_"_M7
MF0`5`/]C_U/[`0`<>[/P`F0#`":`#`!``#0[5/]K_U-%`Q4`A```'(2@\P(`
MQ!A49`,`)Y]0_T/_X_]3_XO]5P0$@`+_H_I7``!``XD`%0"D`0`<#-"N`PP`
M`!:,`0`#A#`,.&4`P"AF(,`"8Q!%`&,000"G`0`<#,"M`PP``!:,`0`#YS`,
M.*@!`!P,,*P##```%HP!``,(,0PX:@`5`*$!`!P,\*P##```%HP!``,A,`PX
M(0``3*$!`!P,$*P##```%HP!``,A,`PX(0``3```0`-CP/\"=B#`*79`P`+$
M`0`<A-#B`LP!`!R,L>("A!T`6,P!`!R,`>LH@!$`0'8@P"AC0,`"@`$`3'8@
MP"AC0,`"(```3,0!`!R$\.$"Q0$`'*70X0*ED!$`I0Q)`&/`_P*L_$4`=B#`
M*865$`!V0,`"I01)`*`<`$#,`0`<C.'I*(`1`$!V(,`H8T#``H`!`$QV(,`H
M8T#``B```$QC@/\"=D#`*7<@P"EA8,`I=H#``M<!`!SW0NH"[`(`*H`U`$3,
M`0`<C('I*(`=`$#,`0`<C+'I`H0!`";!`0`<(2#I*"$``$S_'_]7#`2``NP"
M`"EA8,`H=D#`*'<@P"AC@,`"(```3&/`_P)V(,`I=D#``G8@P"AC0,`"_R__
M4](!`!Q2<N8H3`(`)F-`]0)M(,`"Y0$`%&&@RBEW@,HI>&#**7E`RBEL(,HI
MD>#``H?@P0*S`14`I0"\`P;^`10P`@`F+@(`)#$BP`(/@D4`#*)%`/1A00`0
MXD4`C)44`(Q!%0#.,0``D`+?`.\A00#.P4P`C$$5`.^9%`#.`=\`C#T5`&X"
M`"=L(L`I<T+``O&P_U^Q`<@"K*'!*+`!P2BO0<`HK@$`)HS!%0",O14`C+D5
M`(X%00",?44`S#$5`(P!WP"L`<(IK2'``K'-_U^4```FD$#`*)%@P"AF(,`H
MCR#`*).`P"CE!+44I62F`XUN10",%D$`C#45`,:4$``-QA4`YWE!`,;,$`"M
MO10`[@E%`(P!WP#N.!4`K<45`(R9$`!H0,`HQ@'?`(RU$`",`=\`#9H5`(EM
M10`(E1``AQ5!`*W1%``(Q1``K<$5`.<D%0"MH1``YP#?`(EZ00"MG1``B`I%
M`&=@P"@H(14`K0'?`,ZA%0"J;44`SK$4`.>4$`"I%4$`Y\`0`,Z9%0`I*14`
MSIT0`"D!WP"'>4$`:H#`*(P)10#G,!4`S*40`(P!WP`.G14`B15!`(MM10`(
M`=\`SK44`$J5$`!*F1``SJ$5`"8M%0#.J1``Q@#?`*EY00!JH,`HK0E%`"DU
M%0#-F1``I@'?`.VD%0!*E1``RVQ%`.<`WP"ML10`SA1!`$BA$`"MG14`SBT5
M`*VA$`#.`=\`B'E!`(P)10`(,14`K+D0`&W`P"B.`=\`+*$5`*V5$``I`=\`
MRVU%`(R9%`#*%4$`IYT0`(RE%0!*+14`C)T0`$H!WP#-"$4`C*D0`,=X00!J
MX,`HYS05`(T!WP`,G14`IA5!`*MM10`(`=\`C+D4`$J5$`!*I1``C*$5`,DL
M%0",J1``*0'?`,9Y00!J`,$HS@E%`,8X%0",I1``C@'?`.R8%0!*E1``RVU%
M`.<`WP",M10`R15!`$BA$`",G14`*2T5`(RA$``I`=\`J'E!`&H@P2BM"44`
M"#45`(RE$`"-`=\`S*`5`$J5$`"K;44`Q@#?`(RY%`"I%4$`1YT0`(R9%0`I
M+14`C)T0`"D!WP#'>4$`:D#!*,X)10#G.!4`C*40`(X!WP`,G14`2I40`,MM
M10`(`=\`C+44`,D500!&F1``C*$5`"DM%0",F1``*0'?`*9Y00!J8,$HK0E%
M`,8T%0",I1``C0'?`.R8%0!*E1``JVU%`.<`WP",N10`J15!`$BA$`",G14`
M*2T5`(RA$``I`=\`R'E!`&J`P2C."44`"#D5`(RE$`".`=\`S*`5`$J5$`#+
M;44`Q@#?`(RU%`#)%4$`1YT0`(R9%0`I+14`C)T0`"D!WP"G>4$`:J#!**T)
M10#G-!4`C*40`(T!WP`,G14`2I40`*MM10`(`=\`C+D4`*D500!&F1``C*$5
M`"DM%0",F1``*0'?`,9Y00!JP,$HS@E%`,8X%0",I1``C@'?`.R8%0!*E1``
MRVU%`.<`WP",M10`R15!`$BA$`",G14`*2T5`(RA$``I`=\`J'E!`&K@P2BM
M"44`"#45`(RE$`"-`=\`S*`5`$J5$`"K;44`Q@#?`(RY%`"I%4$`1YT0`(R9
M%0`I+14`C)T0`"D!WP#'>4$`:@#"*,X)10#G.!4`C*40`(X!WP`,G14`2I40
M``@!WP#+;44`C+44`,D500!&F1``C*$5`"DM%0",F1``*0'?`*9Y00!J(,(H
MK0E%`,8T%0",I1``C0'?`.R8%0"I%4$`YP#?`*MM10",N10`2I40`$JA$`",
MG14`*"T5`(RI$``(`=\`R7E!`&I`PBC."44`*3D5`(RA$`".`=\`S*05`,@5
M00#&`-\`RVU%`(RU%`!*E1``2IT0`(R9%0`'+14`C*D0`.<`WP"H>4$`:F#"
M**T)10`(-14`C)T0`(P!WP`MH14`AQ5!`(MM10`I`=\`K;D4`$J5$`!*F1``
MK:45`.8L%0#'>4$`S@E%`.<X%0"MJ1``;H#"*,8`WP"FF1``R@#?``V=%0#%
ME1``2VU%``@!WP"ML10`3A5!`*FD$`"MH14`SBT5`*VE$`#.`=\`B7E!`&N@
MPBB,"44`K;D0`"DQ%0#.L]T4SH6N`Z4!WP#LI!4`:[D0`+=L10",F14`IA1!
M`&BA$`#&7!4`C`'?`(RA$`#&`-\`AID0`$AY00!LP,(H2@E%``@I%0`KH14`
MR@#?`/<`WP",N1``9[45`$MM10!-%4$`C-T0`.<`WP"M+14`C)T0`*T!WP"G
M>$$`I0A%`.<4%0"%M1``;.#"**L`WP`-G14`=VU%`(RY$``I`=\`IID5`&T5
M00",I1``Q@#?`*U=%0",F1``K0'?`(VU$`!&>4$`;`##*$H)10#&*!4`Z9@5
M`*H!WP`7`=\`C+D0`"B5%0!);44`115!`(S=$``(`=\`I205`(RA$`"E`-\`
MA940`&AY00!L(,,H:PE%``@M%0"I`-\`RZ`5`/<`WP",N1``9[45`"MM10`M
M%4$`C-T0`.<`WP"M+14`C)T0`*T!WP"-M1``1WE!`&Q`PRA*"44`YR@5``N=
M%0"J`=\`UP#?`(RY$`!FE14`2VU%`$4500",W1``Q@#?`*4L%0",F1``I0#?
M`(65$``F>4$`;&##*"D)10#&)!4`ZY@5`*D`WP`7`=\`C+D0`&BU%0`K;44`
M+15!`(S=$``(`=\`K2T5`(RA$`"M`=\`C;40`$AY00!L@,,H2@E%``@I%0#+
MH!4`J@'?`/<`WP",N1``9Y45`$MM10!%%4$`C-T0`.<`WP"E+!4`C)T0`*4`
MWP"%E1``)WE!`&R@PR@I"44`YR05``N=%0"I`-\`UP#?`(RY$`!FM14`*VU%
M`"T500",W1``Q@#?`*TM%0",F1``K0'?`(VU$`!&>4$`;,##*$H)10#&*!4`
MZY@5`*H!WP`7`=\`C+D0`&B5%0!+;44`115!`(S=$``(`=\`I2P5`(RA$`"E
M`-\`A940`"AY00!LX,,H*0E%``@E%0#+H!4`J0#?`/<`WP",N1``9[45`"MM
M10`M%4$`C-T0`.<`WP"M+14`C)T0`*T!WP"-M1``1WE!`&P`Q"A*"44`YR@5
M``N=%0"J`=\`UP#?`(RY$`!FE14`2VU%`$4500",W1``Q@#?`*4L%0",F1``
MI0#?`(65$``F>4$`;"#$*"D)10#&)!4`ZY@5`*D`WP`7`=\`C+D0`&BU%0`K
M;44`+15!`(S=$``(`=\`K2T5`(RA$`"M`=\`C;40`$AY00!L0,0H2@E%``@I
M%0#+H!4`J@'?`/<`WP",N1``9Y45`$MM10!%%4$`C-T0`.<`WP"E+!4`C)T0
M`*4`WP"%E1``)WE!`&Q@Q"@I"44`YR05``N=%0"I`-\`UP#?`(RY$`!FM14`
M*VU%`"T500",W1``Q@#?`*TM%0",F1``K0'?`(VU$`!&>4$`;(#$*$H)10#&
M*!4`JP'?`.J8%0`7`=\`C+D0`$B5%0!J;44`915!`(S=$``(`=\`I2@5`(RA
M$`"E`-\`A940`"AY00!LH,0H*0E%``@E%0"J`-\`R:`5`/<`WP",N1``)[45
M`$EM10!-%4$`C-T0`.<`WP"M)14`C)T0`*T!WP"-M1``:7E!`&S`Q"AK"44`
M*2T5``>E%0"K`=\`UP#?`(RY$`#EE!4`9A5!`&=M10",W1``I0#?`,8<%0",
ME1``Q@#?`(:9$`!'>4$`;.#$*$H)10#G*!4`)9T5`,H`WP!7;44`C+D0``@!
MWP"MM!4`115!`(RA$`"M`=\`I5P5`(RU$`"E`-\`C)40`&UY00!E`,4H:PE%
M`*TM%0"(`=\`[+05`*6X$``I`=\`CID5``9M10`,%4$`I:00`,X!WP",&14`
MI;@0`(P!WP!.>4$`I;`0`$H)10!F(,4H;#<>%<XI%0",<;,##```%LD!WP"J
M`=\`K3D5`*4`WP!8I10`ZP#?`*VA%`#&L!``MVQ%`,:L$`"G%$$`K6$5``MY
M00#G7!4`K9D0``8)10!F&14`YP#?`&M`Q2BMG1``K0'?`,@`WP#.&14`.*$4
M`&NQ$`"W;44`SI44`*<500!JJ1``SF$5`.=<%0#.J1``YP#?`*IX00!K8,4H
MI0A%`$45%0#.G1``QP'?`*H`WP#&%!4`&*D4`.X400#W;$4`QK04`&NQ$`!K
MI1``QF`5`,E=%0#&K!``*0'?`*YY00!K@,4HK0E%`,XU%0#-I!``I@'?`,D!
MWP"E.!4`6*44`,T400#7;$4`I9P4`&NQ$`!KH1``I6`5`*A=%0"EK!``"`'?
M`.UX00!KH,4HYPA%`*T=%0"EH!``IP#?`*@!WP#.-14`.*$4`.4400#W;$4`
MSID4`&NQ$`!KJ1``SF$5`*I<%0#.K1``2@'?`,5X00!KP,4HQ@A%`*48%0#.
MJ1``Q@'?`*H`WP"M%14`&*D4`,X400#7;$4`K9T4`&NQ$`!KI1``K6$5`,E=
M%0"MK1``*0'?`.YX00!KX,4HYPA%`,X=%0"MI1``IP'?`,D!WP"E.!4`6*44
M`.T400#W;$4`I9@4`&NQ$`!KH1``I6`5`*A=%0"EK!``"`'?`*6@$`#->$$`
MQ@A%`*T9%0"F`-\`90#&**L!WP#.-14`.*T4`*6P$`#7;$4`SIT4`,@400"J
MJ!``SF$5``A=%0#.J1``"`'?`.5X00!J(,8HYPA%`*4<%0#.H1``QP'?`*@`
MWP"M%14`>*$4`.X400#W;$4`K9D4`$JQ$`!*I1``K6$5`,E=%0"MJ1``*0'?
M`*VE$`#.>$$`Q@A%`,X9%0"F`=\`;4#&*,H!WP"E.!4`&*D4`*VQ$`#7;$4`
MI9P4`,D400"KK1``I6`5`"E=%0"EK!``*0'?`.UX00!K8,8HYPA%`*T=%0"E
MI!``IP#?`*D!WP#.-14`6*44`.4400#W;$4`SID4`&NQ$`!KH1``SF$5`*A<
M%0#.K1``"`'?`,ZA$`#%>$$`Q@A%`*48%0#&`=\`;H#&**L`WP"M%14`.*T4
M`,ZQ$`#7;$4`K9T4`,@400#*J1``K6$5``A=%0"MJ1``"`'?`.YX00!JH,8H
MYPA%`,X=%0"MH1``IP'?`,@!WP"E.!4`>*$4`.T400#W;$4`I9@4`$JQ$`!*
MI1``I6`5`*E=%0"EJ!``*0'?`*6D$`#->$$`Q@A%`*T9%0"F`-\`9<#&**H!
MWP#.-14`&*D4`*6P$`#7;$4`SIT4`,D400"KK!``SF$5`"E=%0#.K1``*0'?
M`.5X00!KX,8HYPA%`*4<%0#.I1``QP'?`*D`WP"M%14`6*44`.X400#W;$4`
MK9D4`&NQ$`!KH1``K6$5`,A=%0"MK1``"`'?`*VA$`#.>$$`Q@A%`,X9%0"F
M`=\`;0#'*,L!WP"E.!4`.*T4`*VQ$`#7;$4`I9P4`,@400"JJ1``I6`5``A=
M%0"EJ!``"`'?`.UX00!J(,<HYPA%`*T=%0"EH!``IP#?`*@!WP#.-14`>*$4
M`.4400#W;$4`SID4`$JQ$`!*I1``SF$5`*E<%0#.J1``*0'?`,ZE$`#%>$$`
MQ@A%`*48%0#&`=\`;D#'**D`WP"M%14`&*44`,ZQ$`#7;$4`K9T4`,H400#+
MK1``K6$5`$I=%0"MK1``2@'?`.YX00!K8,<HYPA%`,X=%0"MJ1``K0'?`,<!
MWP"E.!4`.)T4`*H500"W;44`I9@4`&NQ$`!KH1``I6`5`$A=%0"EK!``=X#'
M*`@!WP#*>$$`Q@A%`$H9%0"EH!``JP#?`$@!WP#.*14`SK44`/F@%`#WLA``
M>&U%`&8500#IIA``S&45`,9@%0",I1``K@E%`*EY00#&`-\`*3D5`(:9$`#8
M`-\`3:45`(S%E!5NH,<H"F]%`*V5%0",68<#!1=!``P``!:E*!4`:GE!`&L)
M10!*+14`SK$0`,>=$`"M`=\`+JD5`*V=$`#.F14`I0#?`&;`QRBEE1``MP#?
M`,:P$`#G;D4`[19!`,B@$`"M'14`S@'?`,ZA$`"M`=\`SK40``A[00!MX,<H
M&`M%``AA%0#+`=\`1J$5`&=M10"ML1``*0'?`,64%0!F%4$`K:40`*4`WP#&
M'!4`K940`,8`WP"FF1``YWI!`&T`R"CW"D4`YUP5``6=%0#7`-\`Z6Y%`*VQ
M$`!*`=\`KK@5`.4600"MJ1``S@'?`*4D%0"MN1``I0#?`*65$`!I>4$`;2#(
M*&L)10`I+14`[J05`*L`WP!J;44`K;$0``@!WP#&F14`;A5!`*VA$`#&`-\`
MSBD5`*V9$`#.`=\`KKD0`.AZ00!M0,@H]PI%``A=%0#*`=\`)J$5`%=M10"M
ML1``YP#?`,:4%0!%%4$`K9T0`,8`WP"E7!4`K9D0`*4`WP"EE1``9WE!`&U@
MR"AK"44`YRP5``:=%0"K`-\`=VU%`*VQ$``I`=\`QK@5`&X500"MI1``Q@#?
M`,Y=%0"MF1``S@'?`*ZY$`!&>4$`;8#(*$H)10#&*!4`Z9@5`,H!WP`7`=\`
MK;$0`"B5%0!);44`115!`*W=$``(`=\`I205`*VA$`"E`-\`I940`&AY00!M
MH,@H:PE%``@M%0"I`-\`RZ`5`/<`WP"ML1``9[D5`"MM10`N%4$`K=T0`.<`
MWP#.+14`K9T0`,X!WP"NN1``1WE!`&W`R"A*"44`YR@5``N=%0#*`=\`UP#?
M`*VQ$`!FE14`2VU%`$4500"MW1``Q@#?`*4L%0"MF1``I0#?`*65$``F>4$`
M;>#(*"D)10#&)!4`ZY@5`*D`WP`7`=\`K;$0`&BY%0`K;44`+A5!`*W=$``(
M`=\`SBT5`*VA$`#.`=\`KKD0`$AY00!M`,DH2@E%``@I%0#+H!4`R@'?`/<`
MWP"ML1``9Y45`$MM10!%%4$`K=T0`.<`WP"E+!4`K9T0`*4`WP"EE1``)WE!
M`&T@R2@I"44`YR05``N=%0"I`-\`UP#?`*VQ$`!FN14`*VU%`"X500"MW1``
MQ@#?`,XM%0"MF1``S@'?`*ZY$`!&>4$`;4#)*$H)10#&*!4`ZY@5`,H!WP`7
M`=\`K;$0`&B5%0!+;44`115!`*W=$``(`=\`I2P5`*VA$`"E`-\`I940`"AY
M00!M8,DH*0E%``@E%0#+H!4`J0#?`/<`WP"ML1``9[D5`"MM10`N%4$`K=T0
M`.<`WP#.+14`K9T0`,X!WP"NN1``1WE!`&V`R2A*"44`YR@5``N=%0#*`=\`
MUP#?`*VQ$`!FE14`2VU%`$4500"MW1``Q@#?`*4L%0"MF1``I0#?`*65$``F
M>4$`;:#)*"D)10#&)!4`ZY@5`*D`WP`7`=\`K;$0`&BY%0`K;44`+A5!`*W=
M$``(`=\`SBT5`*VA$`#.`=\`KKD0`$AY00!MP,DH2@E%``@I%0#+H!4`R@'?
M`/<`WP"ML1``9945`$<500!+;44`K=T0`*4`WP#G+!4`K940`.<`WP"GG1``
M)7E!`&W@R2@I"44`I205``N5%0#I`-\`K;$0`-<`WP!NN14`)A5!`"MM10#.
M`=\`K=T0`,8L%0"MN1``Q@#?`*V9$`"F`=\`3GE!`&T`RBA*"44`SBD5`*JX
M%0"LL1``1YT5``@!WP#-%$$`RFQ%`(RA$`#G`-\`K2D5`*T!WP",G1``C+40
M`(P!WP`M>4$`C-$0`"D)10",`=\`K245`(P``">M`=\`S@'?`*P`WP"MP1``
MSL40`.^9$`",S1``<2#**%`"`";O`=\`K0'?`,X!WP",`=\`CR#`*8U`P"F.
M8,`IC(#`*3`>`%QAH,HH=X#**'A@RBAY0,HH8\#*`B```$S_V^178P#_`F'@
MP"EWP,`I>*#`*7F`P"EZ8,`I>T#`*7P@P"E]```G@/@`0(P!`!R,4<HHG0$`
M)J#K`$",```H@!$!0`WT@`(9`!4`K'$`7+<#`";@/@!`NP`5`)H`%0"X`Q4`
M'/2``N0"%0`F`Q4`10,5`/\'X5>`#`!$[&8`.)QA`%@8(\`"%P,`)O_>_T=A
MX,`HY`(5`'?`P"AXH,`H>8#`*'I@P"A[0,`H?"#`*'T``"9C`,$"(```3(P`
M%0`.](`"C`7``HT!`"B@"0!`S?7_7YF1$0`Y@T``_W?_4QCW$0`8#TD`>`,`
M)6'@P"@Y!\`"]^80`.0"%0!WP,`H>*#`*'F`P"AZ8,`H>T#`*'P@P"A]```F
M8P#!`B```$QAX,`H%P`5`.0"%0!WP,`H>*#`*'F`P"AZ8,`H>T#`*'P@P"A]
M```F8P#!`B```$P9`!4`___^4V,`_P)Z8,`IF@$`'%H#Q2A,`P`F=\#`*7B@
MP"EY@,`I8>#`*9@`%0!W$,`";"#`*9D!`!PYX\0HY0(5``0#%0#_;_Y7@#P`
M0"T#`"9L!``DC#4M`(TAP"B-`0`GO]W_0XPAP`*-(<`HC0$`)[_U_T?E`A4`
M!`,5`/\W_E>?S/]';2#`*$P#`":L(0!<8>#`*'?`P"AXH,`H>8#`*'I@P"AC
M`,$"(```3/_;XE=C@/X">0#!*9D!`!PY4\(H=T#!*7@@P2EA8,$I>N#`*7O`
MP"E\H,`I?8#`*7Y@P"E_0,`I+@,`)JT``"@,](`";B#`*;<`%0"8`!4`K`D`
M7+<$P`+D`A4`_U_?5YH`%0!E$,`"!`,5`/^;_5>;`!4`@$`!0/]#WU>:#`%L
M?00`))P!`!R<\\`HO0]!``P#`"B`S0%`#?2``JS%`5@,`Q4`#O2``@`(`%#-
M$0!8C`7``HT!`"B_]?]'C.$1`(R!0`"-`P`F1`O``H2P$`"]]1``__?>5Z0#
M`">`?`%`C0,`)FP$`"0.`P`H!`?``HPU+0"-`0`FK@$`*<`M`$`,](`"CB4`
M6`[T@`(`"`!0S!D`6(0$P`*,_#\HK07``JP!`"F?[?]'#O2``JP%P`*N`0`I
M]P;``NW^/RB,!<`"C?T_*;_Q_T<$`!4`;2#`*"P#`":L(0%<86#!*'=`P2AX
M(,$H>0#!*'K@P"A[P,`H?*#`*'V`P"A^8,`H?T#`*&.`P0(@``!,]P;``NS^
M/RA[!\`";/\_*9^Q_T/W!L`"[/X_*'L'P`)L_S\IG]W_1_^;_U.<`0`<G#/\
M*)\#`";L`P`F@*4`0.P#%0`.`!4```@`4*X!%0",(<`"CP$`)LT%@`*[`14`
M_^W_1\X-@`+$#4$`K`$`'(SQ_`*-`0`DH#T`1`T$@`*-`0`E_[_=5YX`%0"`
M1`!`?0]!`*8#%0#E`Q4`_U??5YX#`"=^>RT`P"/`*7L0@"G_6_Y3A0`5`.0#
M%0#_U]]7A`,`)YX`%0!]#T$`G]C_1P3\OP+_\_Y3#``5`/]C_E,$0(`"&P`5
M`/^'_U/_9^!78T#\`GD@PRF9`0`<.8/X*"P#`"9AH,,I=H##*7=@PREX0,,I
M>@##*7O@PBE\P,(I?:#"*7Z`PBE_8,(I;"#"*8`0`$",```HF``5`(!%`$1M
M(,(H+`,`)JPY`5QAH,,H=H##*'=@PRAX0,,H>2##*'H`PRA[X,(H?,#"*'V@
MPBA^@,(H?V#"*&/`PP(@``!,_[/?5YH`%0"?N/]#6P``''M3^@)<```<G%/Z
M`EX``!S>4_H"?R#``AW\OP)$`Q4`_Z/<5X"L`$"73,`"90,5`.0"%0#_W]U7
MG^3_0X4#%0#D`A4`_\_=5Y_4_T,$`Q4`_U/<5Y8`%0#D`A4`_T?<5\22$`"$
M@$``A`B``O]'W%<&_+\"!02``ND"%0`(`Q4`QP,5`)8`%0#_Z]Y7Y@,5`,4"
M%0`$`!4`_SO=5YT8`%AL&``D[0$`%(X``!2,M10`CC4`6,0"%0#_N]Q7Q`(5
M`/^3W5=$`Q4`__O;5Y]<_T=$`Q4`_^_<5P0#%0#_9]Q7_]/^4\0"%0#_>_Y7
M_]/_4__3WE=C0/T"=X#"*9<!`!SW,O(H[`(`)GA@PBF%`!4`F``5`&8@P`($
M`!4`8:#"*6P@PBG_#]Y7@#0`1&P8`"3N`0`4C0``%(RY%`"-#0!830$`%(T=
M`%P%"(`"!`,5`/^#VU>$!$`"``@`4`0`%0!M(,(H[`(`)JP9`%QAH,(H=X#"
M*'A@PBACP,("(```3/]#WE=CP/X"=P#!*7C@P"GM__\5F`$`'!C3[R@W```4
M><#`*7J@P"EA(,$I>X#`*7Q@P"D,`P`F8[00`+H`%0#M0H`#Q?__%:V-$`"E
MX+\#F0`5``;\OP.EE1``1```'(0P\P)L"!`G_[O;5X2`0``$^`!D[4*``ZV-
M$`#L__\5K+$0`)O\OP*,[1``C.$_*(T!`!RM(>XHO`$`)("%`$1@LP!`+```
M%-?__Q6,08`#]^*_`XR-$`"7W1``9@,5``6\@`+D`A4`_XO<5X"$`$"$`Q4`
M___:5V<#%0#F`A4`)0,5`/_?VU=M"!`F#`,`)JR=`%PM```48[00`&$@P2AW
M`,$H>.#`*'G`P"AZH,`H>X#`*'Q@P"AC0,$"(```3"P``!37__\5C$&``_?B
MOP.,C1``FP`5`)?=$`!F`Q4`!;R``N0"%0#_"]Q7GX3_1X0#%0#_?]I71@,5
M`"4#%0#_4]I7_X?_4XP!`!R,P>HHG`$`)(0#%0#_6]I71@,5`"4#%0#_+]I7
M_V/_4_^WW%>,`0`<C"'J*(0!`"1CP/\"82#`*?\OVE=A(,`HQP``'.=0[@*&
M`0`<QE#J*$4``!RE\.T"8T#``O\[W%-CP/\"=P``)Y<!`!SW$NDHY`(`)&$@
MP"G_[]E7_ZO_5^0"`"3_X]E782#`*'<``"9(```<"#'[`@D`%0`'`14`)@``
M',8PUP)%```<I1#M`F-`P`+_@]I38\#^`GG`P"F9`0`<.7/G*"P#`";-__\5
M82#!*7<`P2EXX,`I>J#`*7N`P"ECM!``;!@@)UH``!3_)]I7M___%4R#@`.,
MC1``]Z*_`Y?=$``F```4B``5`$D``!PIT>L"1P``'.?0ZP+&!(`#!02``N0"
M%0#_6]M7V/__%4R#@`.,C1``&,._`YCA$`#D`A4`)@``%`4#%0#_9]E7EX!`
M`.!F`&#D!H`"_V?85YH`%0"`'`!`^P(5`.8"%0`%`Q4`6^\0`/^+V5=@`P`I
M;1@@)BP#`"9$`Q4`K#4`7$T``!1CM!``82#!*'<`P2AXX,`H><#`*'J@P"A[
M@,`H8T#!`B```$P:`!4`_\?_4_\3VU?_\_Y38\#\`GQ@PBGM__\5G`$`')P3
MXR@N```4=P##*7C@PBEYP,(I?4#"*6$@PREZH,(I>X#"*8P#`"9CM!``W?__
M%<Y!@@.MT[T#SHT0`)D`%0"W`!4`1```'(3PYP+%M1``;(@0)__3]5>8`!4`
M!;R``B0#%0#_5]E7@%0`0"4#%0!$```<A(#G`O^O]U<D`Q4`;8@0)HP#`":L
MH0%<+0``%&.T$`!A(,,H=P##*'C@PBAYP,(H>J#"*'N`PBA\8,(H?4#"*&-`
MPP(@``!,)`,5`/\;UU>;@$``10``'*5@Y@+D`A4`_[?65Y<`%0"?D/]#+0``
M%*Q!@@.ZX[\#C(T0`)KI$`"L08(#C(T0`+WCO0.=]1``[`(`*'L'@`*`R0!`
M`!<`0.4"%0`$`Q4`_R_85X"4`$#D`A4`_[/65X2`0`#LDA``C?T_*`R\@`*L
M'0!<#KR``H3\OP+LDA``C?T_*(`!`"FN\?];9!,0``S\OP.$#?]C)@``%`4$
M@`(J`Q4`20``'"GAXP+H`A4`1P``'.?0XP)$`Q4`_R/95Z8#%0!%`Q4`!``5
M`/]SUU>`&`!$;!@`).X!`!0-`0`4C+D4`(U-`%A%```<I;#B`@0`%0#_R]57
MEP`5`)^D_D/L`@`HGT'_1P`;`$`E```<I<#?`@0#%0#_9]=7G\S_0S<``!SW
M<M\"!`2``O]C_U,%!(`"1`,5`/\'UE>?K/]'10,5`$0``!R$`.$"_P_V5T0#
M%0#_V]=7_U_^4__3V%>.```HC0`5`,`E`$"M!<`"S+W``ZX!`"B$,!,`K+$3
M`(0P%0#?Z?]'(```3"```$R`!`%`8\#_`G<``"=A(,`IC```*)<`%0"`30!`
M_V/55X;\_P+FFA``YFX`;,T``"@,O(`"K$D`7`V\@`(`#`!0S```*(TY`%S&
M_/\"YO;_7\T``"@,O(`")```'(30W@*L#0!<)```'(0@W`)A(,`H=P``)F-`
MP`+_)]=3#;R``@`,`%#,```HC1$`6,;\_P+F]O]KYK[_6PV\@`(`#`!0S```
M*(T-`%S&_/\"YO;_:\;<$0#-",`"+```%(TU`&CE`A4`)P``%,8$P`)D`0`<
MA*#8`O_;UU=A(,`H=P``)F0!`!R$4-@"8T#``B```$QA(,`H=P``)@0`%0!C
M0,`"(```3"0``!R$H-D"_Y/64V.`_@*L```<C('9`G@@P2EX`0`<&!/5*)`!
M`":/(<`HCD'`*(UAP"@1`P`FC(%`*B0``!R$<-L"86#!*7'@P"EP0,`I;V#`
M*6Z`P"EMH,`I;,!`*7=`P2G_M_-7)```'(0`VP+_J_-7)```'(3PV@+_G_-7
M)```'(0`VP+_D_-7)```'(3PV@+_A_-7)```'(0`VP+_>_-7)```'(3PV`+_
M;_-7)```'(3@V@+_8_-7)```'(3PV@+_5_-7)```'(0`VP+_2_-7)```'(1P
MV`+_/_-7=S#``N4"%0`D```<A,#:`O_7\5>`%`!`A0`5`"0``!R$\-D"_\/S
M5^4"%0`D```<A)#:`O^S\5>`%`!`A0`5`"0``!R$H-H"_Y_S5^4"%0`D```<
MA*#:`O^/\5>`2`!`A0`5`"0``!R$<-8"_WOS5R4``!RE`-L")```'(3`UP+_
M9_-7;>#`*`P#`":L;0!<86#!*'=`P2AX(,$H8X#!`B```$SE`A4`)```'(2`
MV0+_-_%7@!@`0(4`%0`D```<A##7`O\C\U?_J_]3!BB``B4``!RE0-D"9(3`
M`O]_TE>?D/]'9:S``B0``!R$@-8"__?R5_]__U/_P]578T#_`G>`P"EW`0`<
M]_+-*.P"`"9X8,`I>`$`'!B3Q0($`P`D;"#`*6&@P"D,_+\"A"4`6&T@P"CL
M`@`FK%4`7&&@P"AW@,`H>&#`*&/`P`(@``!,91#``B0``!R$T-0"_XOP5X`@
M`$",```H!``5`(`-`$"$P<`#!)`2``0#`"7_M_]3!``5``0#`"7_J_]3_R_5
M5V/`_P)A(,`I__/15_^OU%>`"`!`A```)F$@P"AC0,`"(```3&,`_P)WP,`I
M=P$`'/<2RRCL`@`F>8#`*640P`*9`!4`)```'(20U0)AX,`I>*#`*7I@P"EL
M(,`I__OO5R4#%0"`$`!`C```*)@`%0"`.0!$)```'(30U`+_V_%7;2#`*.P"
M`":L>0!<8>#`*'?`P"AXH,`H>8#`*'I@P"AC`,$"(```3/\CTE>?U/]')`,5
M`/]7T5>:`!4`!`,5`/]+T5=$DQ``A`C``O]/T5<%!(`""@,5`"D``!PIX<X"
M*`,5`"<``!SG\,X"!OR_`IH`%0#_Y]-710,5`/][_U/_*]178P#Y`@W__Q5Z
M0,8I>R#&*6'@QBEVP,8I=Z#&*7B`QBEY8,8I?`#&*7W@Q2E^P,4I?Z#%*6P!
M`!R,`?X"8[00`!0!`!1[`0`<>Z/&*(VAP"AF0,`"<P,`)H5"A0.2`0`FD2'`
M*)!!P"B/8<`HCH'`**68$``,__\5F@`5`(1"A0.4(H4#K+`0`)2:$`#E_O\5
MA)@0`*4PNP.3`@`GC:'\*3,``!QSDM`"+0``'*TQT`*%E!``DT'[*8VA^RDS
M```<<^+(`BT``!RM(=`")```'(2`R@*38?LI@('[*9(!_"F1(?PID$'\*8]A
M_"F.@?PIC<'[*8#A^RG_6^Y7@!``0(P``"B7`!4`@`$%1/_S_5>7`!4`@$`$
M0.0"%0#_Z\]7A`1!`(0$P`+_[\]7[`(`*)P`%0"`.0!`F`,5`#D``!PY@\X"
MZ`(`*@0#%0`G`Q4`!OR_`@4$@`+W!L`"_WO25^P"`"@8"\`"G]W_1PT!`!2N
M084#;T#``@S__Q7.O1``S+$0`(0!_"B`:`!`^?[_%:Q!A0,W`[P#C+T0`)?=
M$`"L084#.3.[`XR]$`"9Y1```!``4/<BP`+D`@`F@#0`0"4#%0#_C^U7F``5
M`)_H_T.,```HG^'_0_^#\U>?V/]#!`,5`/]#T5>=`!4`@%P`1`P!`!2,084#
M;4#``AG__Q6,M1``&``5`)GE$``,9RT`ET'[*.`R`$#L`@`H@"D`0.0"%0#_
M-_-7&`>``I_@_T/D`A4`__/05Y_4_T.=`!4```@`4!T`%0"D`Q4`_[O.5Y<`
M%0"$`Q4`_Z_.5^R2$`",@4``C!&0`H0!%0"7`14`_Z?.5XL#%0`J```<2K')
M`BD``!PI4<0"J`,5`"<``!SG@,D"!OR_`@4$@`*9`!4`_S?15P4`AP(D`Q4`
M_TO05PS\OP*,%`!<_]_-5XD``"0,1(`"B1D#7!X!`!1M0,`"_/[_%<Q#A0.,
MM1``AL.\`X:9$``E`Q4`!``5`/^KT%>8`!4`@(@`0&P!`!R,4?TH1P,`)H0!
M`"8H`Q4`)@``',;`R`(%!(`"_X_05Q<`%0`,`0`4;4#``HPAA0.,M1``C0$`
M)FP#`";D`A4`K'T*7`T!`!1CM!``8>#&*';`QBAWH,8H>(#&*'E@QBAZ0,8H
M>R#&*'P`QBA]X,4H?L#%*'^@Q2AC`,<"(```3&U`P`+,0X4#C+40`!W__Q6=
M]1``K$/_).X!`!2-```4C+D4`(U9_U^^2_\D_T_-5YY,_U^L0_\D#0"'`HS]
M1P.-/?]?Y`(5`/]3S5<,`0`4C$&%`VU`P`*%,[L#C+40`)<`%0"%E1``)```
M'(3`Q@+_9^M7@"P"0%P#`";_+\]7A0`5`(0#%0#_&_57G0`5`(`0`D"D`Q4`
M__/,5YR`0``,#(`"A`,5`)PY`&2$\/\")0``'*7`Q0*DDQ``_S_.5X`@`$0,
M$(`"C(,(6(SSOP*LLQ``C?T_*`R\@`*L;0A8_P_Z5X`8`$0%`!4`I`,5`/];
MSU><`!4`@+`!1"4``!RED,`")```'(30_0+_R^Q7_]O-5XH`%0`K```<:V'(
M`BD``!PIX?L"*`,5`"<``!SG4,0"!OR_`@4$@`+D`A4`_QO/5QK\OP(<1(`"
M/P``'/^3QP(^```<WA/[`CT``!R]T\,"`$``4/^SRU>,```DG$4`7/]WS5<8
M!X`"B@`5`'\``"<+`Q4`R0,5`"@#%0"G`Q4`!OR_`@4$@`+D`A4`_[O.5P4`
MAP+D`A4`_\_-5YJX_ULD`Q4`_X/-5^4"%0`D```<A,#X`O\/[%?D`A4`_]?Y
M5__3_5,-`0`4;D#``OG^_Q6L084#C+D0`#DSNP.9Y1``K$&%`QS__Q6,N1``
M)```'(3@_`(8`!4`G/$0`(`H`$`E`Q4`_[_I5Q@'@`*`#`!`C```*(`I`$0,
M<RT`A*'[*)_@_T<$-(`"_U_+5YP`%0`W```<]_+[`O]S^U/_6\U7G]C_0Y<`
M%0#_0_M3;`$`'(S!\2A'`P`FA`$`)B@#%0`F```<QC#\`@4$@`+_J\U7%P`5
M`/\?_5/_&_E7Y`(5`/\7S5>7`!4`_PO]4UT#`";_\_U3!@B``@6XOP+_*\M7
M&@$`%&U`P`+X_O\53$.%`XRU$``8X[\#F.$0``88@`(%`Q4`A`,5`/^/RU=-
M0X4#;D#``JVY$``,__\5K+$0`(WA/RJ@$0!$C>4_*@X,@0*NN098!@`5``4`
M%0"$`Q4`_\?*5Q$!`!1S0,`",$*%`Q#.$`"N=3$5#/__%0RR$`#R_O\5SOFS
M`S!"A0,.```6$,X0`$^;WQ7-I8<52,*\`Q:B$`".`?TI[R6N`ZW!AP-0BLX4
MKF0@%`T``!8/```6$`:,`\[9D0.-0?TID,'\*8_A_"F.(?TI@&']*8"!_2F`
MH;XI+$*%`XS-$`!-XK\#G[40`,SBP`)L0,`I=V#`*08!`!3E`Q4`A`,5`/^K
MRE>=@$``O@,5`!TX`V0,`0`4;4#``HQ!A0.,M1``#?__%9JU$`!.8_TH3X/]
M*,QW10#-.RT`K0'?`*ZY$@#ON1``1*O_)(R]$`!-8_TI3(/]*8`4!4`8`($"
M#!,1`(UU$@">-1,`;$#`**VW$P#>-Q4`A)$0`,8#%0#E`Q4`_YO*5TRK_R3-
M`Q4`C'D0`$RCOBF88?]?Q`(5`+Y[$0#XMQ``_W/05PS\@`*>&05DW@._`MJ;
M1`!=`]\`#`$`%&U`P`*]!\`"C$&%`XRU$`"]&T$`#?__%1WW$`"7M1``!$<`
M*@L'`"H*"P`JY.8]*01+`"H)#P`J"!,`*N3J/2D$3P`J!Q<`*@8;`"KD[CTI
M!%,`*@4?`"H4(P`JY/(]*017`"H3)P`J$BL`*N3V/2D$6P`J$2\`*A`S`"KD
M^CTI!%\`*@\W`"H..P`JY/X]*01C`"H-/P`J#$,`*N0"/BD$9P`J&`/!`N0&
M/BD$:S\JY`H^*01O/RKD#CXI!',_*N02/BD$=S\JY!8^*01[/RKD&CXI!'\_
M*N0>/BD$@S\JY"(^*02'/RKD)CXI!(L_*N0J/BD$CS\JY"X^*023/RKD,CXI
M!)<_*N0V/BD$FS\JY#H^*02?/RKD/CXI!*,_*N1"/BD$IS\JY$8^*02K/RKD
M2CXI!*\_*N1./BD$LS\JY%(^*02W/RKD5CXI!+L_*N1:/BD$OS\JY%X^*03#
M/RKD8CXI!,<_*N1F/BD$RS\JY&H^*03//RKD;CXI!-,_*N1R/BD$US\JY'8^
M*03;/RKD>CXI!-\_*N1^/BD$XS\JY((^*03G/RH!`S\JZZ8]*>2&/BD$ZS\J
MX:(]*>JJ/2GDBCXI!.\_*NFN/2GHLCTIY(X^*03S/RKGMCTIYKH]*>22/BD$
M]S\JY;X]*?3"/2GDECXI!/L_*O/&/2GRRCTIY)H^*03_/RKQSCTI\-(]*>2>
M/BGOUCTIQ`(5`.[:/2GMWCTI[.(]*?\OSE<=]_U?6IM``-YK$0!D0,`HQ@,5
M`*4#%0`'(($"_]/)5PP!`!1M0,`"C$&%`XRU$``-__\5C+40``8!`!3E`Q4`
MA`,5`)ZAOBG_=\=7G8!``+X#%0`=T/QCA`,5`'=@P"C_?\A7#P$`%&Y`P`+L
M084##?__%8RY$`".M1``S%G_)/!!A0-Q0,`"F`$5`(R-:`#=8?\D$,80`(X!
M%0`.NA``K;D0``X`O@(8,P``O3,``(P%@`*NH3TI!N"``AC#3`"]PTP`A`$5
M`.W^_Q7,%`)DO,&\`QSR$`":X\`"!@"!`L8P$0`%`!4`1),0`/]CR%>$`Q4`
M_S?-5X#CP"F``\$I@"/!*8!#P2F`8\$I@(/!*8"CP2D>`0`4;4#``LQ#A0.,
MM1``'/__%9SQ$`#Z_O\5S$.%`XRU$`!$P[P#G8.^*9B3OBF$D1``_^/,5Y`S
M_R2/._\DCD/_)(U+_R2,4_\D<D#``M%#A0-8([\#,<H0`#CB$`#10X4#$#(`
M`.\Q``#.,0``K3$``(PQ``!:P[X#,<H0`!#"3`#OP4P`SL%,`*W!3`",P4P`
M.NH0`(C//"J0P[XIC].^*8[COBF-\[XIC`._*5H'P`(=H\`"/```')RCXP(`
M#`!02`,`*EH'P`($`Q4`AP,5`!@+P`(&_+\"!02``O^[QU>XX_]?#@$`%&]`
MP`+-084#ZO[_%:V]$`!*(;\#JJD0`,U!A0.MO1``#/__%:RQ$``K```<:W'I
M`@D``!PI\=P"*`,5`"<``!SG(.4"!OR_`@4$@`+D`A4`@,$_*?];QU<D`Q4`
M_S/&5^4"%0`$```<A(#;`O^_Y%?D`A4`_X?R5_^#]E,,`0`4;4#``HQ!A0.,
MM1``[?[_%:WAOP.8M1``_R?[4UHCP"A?E_=#1`,5`/\WQ%<,#(`"A(7W;X3P
M_P(E```<I1#C`D23$`#_B\57O1,3`$23$P"]$Q4`_V/W4QT#%0#_,_U3#@$`
M%&]`P`+.084#SKT0`*W!O`/-M1``K>'``L8P$0`%`!4`I)$0`/]'QE?_"_Y3
MC^D_*@X$@0+N1?E?CNT_*LT]^5^.\3\J#2"!`LTQ^5^-]3\J#!2!`JPE^5\&
M"(`"!1B_`H0#%0#_Y\-7!0,5``:D@`*$`Q4`_V?$5RL``!QKH>0""@,5``D`
M`!PI$=@"*`,5`"<``!SG0.`"!OR_`@4$@`+D`A4`_R?&5_]_]U/_;\978P#^
M`F'@P2EWH,$I>(#!*7E@P2EVP,$I>D#!*7L@P2E\`,$I?>#`*7[`P"E_H,`I
M5P$`'/="T"A,`0`<C.'/*(P!`";D`@`D>5#``FQ@P"EY(,`I_Z?#5Y@`%0#D
M`@`D_YO#5PSC`BHE`Q4`C.0"*00``!R$H-8"_Q_A5X`0`$"-```H#,2``JSE
M`EC_4^Y7Y`(`)/]GPU<'+(`"!@2``@4``!REH-X"_R/#5X"X`D!Z`0`<6H/0
M`HQ`P"A.`P`D#02``INAP"C_`@`DKL4`9!Q``!08`!4`&02``GX!`!S>L\\"
MG`.0`QT`D`(`*`!0!4+`*,0"%0#_P\-73@,`)("(`$0M!X`"&`>``KD!%0"N
M>0!DY`,5`/_CPE<'`!4`!@,5`&4#%0#_\\-7@$P"0)```";.`P`F_P(`)`T.
M`"0N.RT`U@$`)JWQ%`"]I?];9```)^0#%0#_H\)7;P``)@<(@`(&`!4`Y0$`
M)O\?Q5>%`!4`Q`(5`/]#PU?_`@`D3@,`))^`_T/-_;\"N'T!6.0#%0#_9\)7
M!PR``@8$@`(%```<I<#:`O\CPE>8`!4`@#0`0.0"`"3_0\)7#$/`*`8``!S&
M8-H"A0$`)O\/PE<,0\`HC`$`)HP-`"2,V78`@-$!1.0"`"3_$\)7!PR``@8$
M@`(%```<I;#9`O_/P5>8`!4`@#0`0&4@P"@$```<A-#.`O^#WU>9`!4`Y`(`
M)"!O`4#_U\%7#$/`*"8#%0"%`0`F_Z?!5^0"`"1X`0`<&'/*`O^WP5>9`!4`
MY`(`)/^KP5<&!(`"!0``'*5`V`+_N\!7A0`5``8``!S&8-@")`,5`/]GP5?D
M`@`D_W_!5V4@P"B`Y`(I!```'(2@S`+_!]]7!`,`)Y<`%0"`H`!`!0"'`N0"
M%0#_D\)7#$2``H01`%B,!(`"#02``JP1`6A,`0`<C,'%*&U@P"B,`0`FK/D`
M7&'@P2AVP,$H=Z#!*'B`P2AY8,$H>D#!*'L@P2A\`,$H?>#`*'[`P"A_H,`H
M8P#"`B```$P-!(`"KH7^9Q@$@`+D`Q4`_^/`5V4#%0#_F\!730,`)`P'@`*8
M`14`_P(`)(WA_V/_6_Y3;`$`'(PQQ@*$`0`F___N5P0#`">7`!4`GTS_1P0`
M`!R$P-0"_SO"5_\"`"3_*_Y3C`0`*)\A_4/_&_U33@,`)/\"`"3-_;\"N`W^
M7_^#_U/_;\!7;`$`'(SAQ`*-`0`F#$/`**4!`":$`0`F_X?D5_^/_E/D`@`D
M_T?`5PQ#P"B%`0`F_\O!5_\C_E/_H\)7;`$`'(SQPP*,`0`FAP`5`.8"%0"%
M`0`F!```'(0PTP+_K\%78X#_`G=`P"EX(,`I86#`*9@`%0#_R^E7C0``*)<`
M%0"@(0!`A`3``JR]P`.-```H]S(3`(RP$P#W,A4`O^G_1_]_[%>`*`!``"<`
M0`P#`"B`'0!`!A"``@4``!RE@,L"Y`(5`/^WOE>`&`!`86#`*'=`P"AX(,`H
M8X#``B```$QA8,`H=T#`*`0#%0!X(,`H8X#``O^'X5-C`/\"=\#`*7F`P"E7
M`0`<]U+L`ED!`!PY4^P".=\1`&'@P"EXH,`I>F#`*7M`P"E\(,`I.0])`"`W
M`$#<`!4`NP`5`)H`%0`8`!4`[`(`)H8#%0!E`Q4`1`,5`!@'P`*!`0!,]R+`
M`CCG_U]AX,`H=\#`*'B@P"AY@,`H>F#`*'M`P"A\(,`H8P#!`B```$P@``!,
M3`$`'(Q1_@*'`0`F#```'H`1OT\!``(``````"X`````````+BX````````E
M<R\E<P```"]P<F]C+W-E;&8O97AE``!$>6YA3&]A9&5R.CIB;V]T7T1Y;F%,
M;V%D97(``````$EN=&5R;F%L<SHZ4$%2.CI"3T]4`````&5X90``````+W!R
M;V,O)6DO)7,``````%!!4E]414U0``````````!005)?4%)/1TY!344`````
M.@`````````O`````````"5S)7,E<P``4$523#5,24(``````````%!%4DQ,
M24(`4$523#5/4%0``````````%!%4DQ)3P``4$%27TE.251)04Q)6D5$`%!!
M4E]34$%73D5$``````!005)?0TQ%04X`````````4$%27T1%0E5'````````
M`%!!4E]#04-(10````````!005)?1TQ/0D%,7T1%0E5'``````````!005)?
M1TQ/0D%,7U1-4$1)4@````````!005)?5$U01$E2````````4$%27T=,3T)!
M3%]414U0`%!!4E]'3$]"04Q?0TQ%04X``````````%!!4E]#3$5!3CT`````
M```Q`````````$Q$7TQ)0E)!4EE?4$%42`!54T52`````%-94U1%30``+W1M
M<`````!54T523D%-10``````````)3`R>`````!P87(M`````"5S)7,E<R5S
M```````````E<SH@8W)E871I;VX@;V8@<')I=F%T92!S=6)D:7)E8W1O<GD@
M)7,@9F%I;&5D("AE<G)N;STE:2D*````````)7,Z('!R:79A=&4@<W5B9&ER
M96-T;W)Y("5S(&ES('5N<V%F92`H<&QE87-E(')E;6]V92!I="!A;F0@<F5T
M<GD@>6]U<B!O<&5R871I;VXI"@```````%!!5$@`````<&%R;``````N<&%R
M`````"5S)7-C86-H92TE<R5S```E<R5S=&5M<"TE=25S````)7,E<W1E;7`M
M)74M)74E<P``````````5$U01$E2``!414U01$E2`%1%35``````5$U0````
M``!!4D=6`````!@`````````<&5R;``````P`````````%!!4CHZ4&%C:V5R
M.CI615)324].`````#$N,#0W````56YA8FQE('1O(&-R96%T92!C86-H92!D
M:7)E8W1O<GD``````````"5S.B!C<F5A=&EO;B!O9B!P<FEV871E(&-A8VAE
M('-U8F1I<F5C=&]R>2`E<R!F86EL960@*&5R<FYO/25I*0H``````````"UE
M````````+2T```````!E=F%L("=E>&5C("]U<W(O8FEN+W!E<FP@("U3("0P
M("1[,2LB)$`B?2<*:68@,#L@(R!N;W0@<G5N;FEN9R!U;F1E<B!S;VUE('-H
M96QL"G!A8VMA9V4@7U]P87)?<&P["FUY("@D<&%R7W1E;7`L("1P<F]G;F%M
M92P@0'1M<&9I;&4I.PI%3D0@>R!I9B`H)$5.5GM005)?0TQ%04Y]*2!["G)E
M<75I<F4@1FEL93HZ5&5M<#L*<F5Q=6ER92!&:6QE.CI"87-E;F%M93L*<F5Q
M=6ER92!&:6QE.CI3<&5C.PIM>2`D=&]P9&ER(#T@1FEL93HZ0F%S96YA;64Z
M.F1I<FYA;64H)'!A<E]T96UP*3L*;W5T<RAQ<7M296UO=FEN9R!F:6QE<R!I
M;B`B)'!A<E]T96UP(GTI.PI&:6QE.CI&:6YD.CIF:6YD9&5P=&@H<W5B('L@
M*"`M9"`I(#\@<FUD:7(@.B!U;FQI;FL@?2P@)'!A<E]T96UP*3L*<FUD:7(@
M)'!A<E]T96UP.PII9B`H+60@)'!A<E]T96UP("8F("1>3R!N92`G35-7:6XS
M,B<I('L*;7D@)'1M<"`](&YE=R!&:6QE.CI496UP*`I414U03$%412`]/B`G
M=&UP6%A86%@G+`I$25(@/3X@1FEL93HZ0F%S96YA;64Z.F1I<FYA;64H)'1O
M<&1I<BDL"E-51D9)6"`]/B`G+F-M9"<L"E5.3$E.2R`]/B`P+`HI.PIP<FEN
M="`D=&UP("(C(2]B:6XO<V@*>#TQ.R!W:&EL92!;(%PD>"`M;'0@,3`@73L@
M9&\*<FT@+7)F("<D<&%R7W1E;7`G"FEF(%L@7"$@+60@)R1P87)?=&5M<"<@
M73L@=&AE;@IB<F5A:PIF:0IS;&5E<"`Q"G@]8&5X<'(@7"1X("L@,6`*9&]N
M90IR;2`G(B`N("1T;7`M/F9I;&5N86UE("X@(B<*(CL*8VAM;V0@,#<P,"PD
M=&UP+3YF:6QE;F%M93L*;7D@)&-M9"`]("1T;7`M/F9I;&5N86UE("X@)R`^
M+V1E=B]N=6QL(#(^)C$@)B<["F-L;W-E("1T;7`["G-Y<W1E;2@D8VUD*3L*
M;W5T<RAQ<2A3<&%W;F5D(&)A8VMG<F]U;F0@<')O8V5S<R!T;R!P97)F;W)M
M(&-L96%N=7`Z("D*+B`D=&UP+3YF:6QE;F%M92D["GT*?2!]"D)%1TE.('L*
M26YT97)N86QS.CI005(Z.D)/3U0H*2!I9B!D969I;F5D("9);G1E<FYA;',Z
M.E!!4CHZ0D]/5#L*979A;"!["E]P87)?:6YI=%]E;G8H*3L*;7D@)'%U:65T
M(#T@(21%3E9[4$%27T1%0E5'?3L*;7D@)4-O;F9I9R`]("@*<&%T:%]S97`@
M("`@/3X@*"1>3R`]?B`O7DU35VEN+R`_("<[)R`Z("<Z)RDL"E]E>&4@("`@
M("`@(#T^("@D7D\@/7X@+UXH/SI-4U=I;GQ/4S)\8WEG=VEN*2\@/R`G+F5X
M92<@.B`G)RDL"E]D96QI;2`@("`@(#T^("@D7D\@/7X@+UY-4U=I;GQ/4S(O
M(#\@)UQ<)R`Z("<O)RDL"BD["E]S971?<')O9VYA;64H*3L*7W-E=%]P87)?
M=&5M<"@I.PIM>2`H)'-T87)T7W!O<RP@)&1A=&%?<&]S*3L*>PIL;V-A;"`D
M4TE'>U]?5T%23E]??2`]('-U8B![?3L*;W!E;B!?1D@L("<\)RP@)'!R;V=N
M86UE(&]R(&QA<W0["F)I;FUO9&4H7T9(*3L*;7D@)&)U9CL*;7D@)'-I>F4@
M/2`M<R`D<')O9VYA;64["FUY("1O9F9S970@/2`U,3(["FUY("1I9'@@/2`M
M,3L*=VAI;&4@*#$I"GL*)&]F9G-E="`]("1S:7IE(&EF("1O9F9S970@/B`D
M<VEZ93L*<V5E:R!?1D@L("TD;V9F<V5T+"`R(&]R(&1I92!Q<5MS965K(&9A
M:6QE9"!O;B`B)'!R;V=N86UE(CH@)"%=.PIM>2`D;G)E860@/2!R96%D(%]&
M2"P@)&)U9BP@)&]F9G-E=#L*9&EE('%Q6W)E860@9F%I;&5D(&]N("(D<')O
M9VYA;64B.B`D(5T@=6YL97-S("1N<F5A9"`]/2`D;V9F<V5T.PHD:61X(#T@
M<FEN9&5X*"1B=68L(")<;E!!4BYP;5QN(BD["FQA<W0@:68@)&ED>"`^/2`P
M('Q\("1O9F9S970@/3T@)'-I>F4@?'P@)&]F9G-E="`^(#$R."`J(#$P,C0[
M"B1O9F9S970@*CT@,CL*?0IL87-T('5N;&5S<R`D:61X(#X](#`["B1O9F9S
M970@+3T@)&ED>"`M(#0["G-E96L@7T9(+"`M)&]F9G-E="P@,CL*<F5A9"!?
M1D@L("1B=68L(#0["G-E96L@7T9(+"`M)&]F9G-E="`M('5N<&%C:R@B3B(L
M("1B=68I+"`R.PIR96%D(%]&2"P@)&)U9BP@-#L*)&1A=&%?<&]S(#T@*'1E
M;&P@7T9(*2`M(#0["FUY("5R97%U:7)E7VQI<W0["G=H:6QE("@D8G5F(&5Q
M(")&24Q%(BD@>PIR96%D(%]&2"P@)&)U9BP@-#L*<F5A9"!?1D@L("1B=68L
M('5N<&%C:R@B3B(L("1B=68I.PIM>2`D9G5L;&YA;64@/2`D8G5F.PIO=71S
M*'%Q*%5N<&%C:VEN9R!F:6QE("(D9G5L;&YA;64B+BXN*2D["FUY("1C<F,@
M/2`H("1F=6QL;F%M92`]?B!S?%XH6V$M9EQD77LX?2DO?'P@*2`_("0Q(#H@
M=6YD968["FUY("@D8F%S96YA;64L("1E>'0I(#T@*"1B=68@/7X@;7PH/SHN
M*B\I/R@N*BDH7"XN*BE\*3L*<F5A9"!?1D@L("1B=68L(#0["G)E860@7T9(
M+"`D8G5F+"!U;G!A8VLH(DXB+"`D8G5F*3L*:68@*&1E9FEN960H)&5X="D@
M86YD("1E>'0@(7X@+UPN*#\Z<&U\<&Q\:7A\86PI)"]I*2!["FUY("1F:6QE
M;F%M92`](%]T96UP9FEL92@B)&-R8R1E>'0B+"`D8G5F+"`P-S4U*3L*)%!!
M4CHZ2&5A=GDZ.D9U;&Q#86-H97LD9G5L;&YA;65](#T@)&9I;&5N86UE.PHD
M4$%2.CI(96%V>3HZ1G5L;$-A8VAE>R1F:6QE;F%M97T@/2`D9G5L;&YA;64[
M"GT*96QS:68@*"`D9G5L;&YA;64@/7X@;7Q>+S]S:&QI8B]\(&%N9"!D969I
M;F5D("1%3E9[4$%27U1%35!]("D@>PIM>2`D9FEL96YA;64@/2!?=&5M<&9I
M;&4H(B1B87-E;F%M921E>'0B+"`D8G5F+"`P-S4U*3L*;W5T<R@B4TA,24(Z
M("1F:6QE;F%M95QN(BD["GT*96QS92!["B1R97%U:7)E7VQI<W1[)&9U;&QN
M86UE?2`]"B1005(Z.DAE879Y.CI-;V1U;&5#86-H97LD9G5L;&YA;65](#T@
M>PIB=68@/3X@)&)U9BP*8W)C(#T^("1C<F,L"FYA;64@/3X@)&9U;&QN86UE
M+`I].PI]"G)E860@7T9(+"`D8G5F+"`T.PI]"FQO8V%L($!)3D,@/2`H<W5B
M('L*;7D@*"1S96QF+"`D;6]D=6QE*2`]($!?.PIR971U<FX@:68@<F5F("1M
M;V1U;&4@;W(@(21M;V1U;&4["FUY("1F:6QE;F%M92`](&1E;&5T92`D<F5Q
M=6ER95]L:7-T>R1M;V1U;&5]('Q\(&1O('L*;7D@)&ME>3L*9F]R96%C:"`H
M:V5Y<R`E<F5Q=6ER95]L:7-T*2!["FYE>'0@=6YL97-S("]<421M;V1U;&5<
M120O.PHD:V5Y(#T@)%\[(&QA<W0["GT*9&5L971E("1R97%U:7)E7VQI<W1[
M)&ME>7T@:68@9&5F:6YE9"@D:V5Y*3L*?2!O<B!R971U<FX["B1)3D-[)&UO
M9'5L97T@/2`B+VQO861E<B\D9FEL96YA;64O)&UO9'5L92(["FEF("@D14Y6
M>U!!4E]#3$5!3GT@86YD(&1E9FEN960H)DE/.CI&:6QE.CIN97<I*2!["FUY
M("1F:"`]($E/.CI&:6QE+3YN97=?=&UP9FEL92!O<B!D:64@)"$["F)I;FUO
M9&4H)&9H*3L*<')I;G0@)&9H("1F:6QE;F%M92T^>V)U9GT["G-E96LH)&9H
M+"`P+"`P*3L*<F5T=7)N("1F:#L*?0IE;'-E('L*;7D@)&9I;&5N86UE(#T@
M7W1E;7!F:6QE*"(D9FEL96YA;64M/GMC<F-]+G!M(BP@)&9I;&5N86UE+3Y[
M8G5F?2D["F]P96X@;7D@)&9H+"`G/"<L("1F:6QE;F%M92!O<B!D:64@(F-A
M;B=T(')E860@)&9I;&5N86UE.B`D(2(["F)I;FUO9&4H)&9H*3L*<F5T=7)N
M("1F:#L*?0ID:64@(D)O;W1S=')A<'!I;F<@9F%I;&5D.B!C86YN;W0@9FEN
M9"`D;6]D=6QE(5QN(CL*?2P@0$E.0RD["G)E<75I<F4@6%-,;V%D97(["G)E
M<75I<F4@4$%2.CI(96%V>3L*<F5Q=6ER92!#87)P.CI(96%V>3L*<F5Q=6ER
M92!%>'!O<G1E<CHZ2&5A=GD["E!!4CHZ2&5A=GDZ.E]I;FET7V1Y;F%L;V%D
M97(H*3L*<F5Q=6ER92!)3SHZ1FEL93L*=VAI;&4@*&UY("1F:6QE;F%M92`]
M("AS;W)T(&ME>7,@)7)E<75I<F5?;&ES="E;,%TI('L*=6YL97-S("@D24Y#
M>R1F:6QE;F%M97T@;W(@)&9I;&5N86UE(#U^("]"4T1004XO*2!["FEF("@D
M9FEL96YA;64@/7X@+UPN<&UC/R0O:2D@>PIR97%U:7)E("1F:6QE;F%M93L*
M?0IE;'-E('L*9&\@)&9I;&5N86UE('5N;&5S<R`D9FEL96YA;64@/7X@+W-I
M=&5C=7-T;VUI>F5<+G!L)"\["GT*?0ID96QE=&4@)')E<75I<F5?;&ES='LD
M9FEL96YA;65].PI]"FQA<W0@=6YL97-S("1B=68@97$@(E!+7#`P,UPP,#0B
M.PHD<W1A<G1?<&]S(#T@*'1E;&P@7T9(*2`M(#0["GT*;7D@0'!A<E]A<F=S
M.PIM>2`H)&]U="P@)&)U;F1L92P@)&QO9V9H+"`D8V%C:&5?;F%M92D["F1E
M;&5T92`D14Y6>U!!4E]!4%!?4D554T5].R`C('-A;FET:7IE("A2155312!M
M87D@8F4@82!S96-U<FET>2!P<F]B;&5M*0HD<75I970@/2`P('5N;&5S<R`D
M14Y6>U!!4E]$14)51WT["FEF("@A)'-T87)T7W!O<R!O<B`H)$%21U9;,%T@
M97$@)RTM<&%R+6]P=&EO;G,G("8F('-H:69T*2D@>PIM>2`E9&ES=%]C;60@
M/2!Q=R@*<"`@(&)L:6)?=&]?<&%R"FD@("!I;G-T86QL7W!A<@IU("`@=6YI
M;G-T86QL7W!A<@IS("`@<VEG;E]P87(*=B`@('9E<FEF>5]P87(**3L*:68@
M*$!!4D=6(&%N9"`D05)'5ELP72!E<2`G+2UR975S92<I('L*<VAI9G0@0$%2
M1U8["B1%3E9[4$%27T%04%]2155317T@/2!S:&EF="!`05)'5CL*?0IE;'-E
M('L@(R!N;W)M86P@<&%R;"!B96AA=FEO=7(*;7D@0&%D9%]T;U]I;F,["G=H
M:6QE("A`05)'5BD@>PHD05)'5ELP72`]?B`O7BTH6T%)34]"3&)Q<&EU<U1V
M72DH+BHI+R!O<B!L87-T.PII9B`H)#$@97$@)TDG*2!["G!U<V@@0&%D9%]T
M;U]I;F,L("0R.PI]"F5L<VEF("@D,2!E<2`G32<I('L*979A;"`B=7-E("0R
M(CL*?0IE;'-I9B`H)#$@97$@)T$G*2!["G5N<VAI9G0@0'!A<E]A<F=S+"`D
M,CL*?0IE;'-I9B`H)#$@97$@)T\G*2!["B1O=70@/2`D,CL*?0IE;'-I9B`H
M)#$@97$@)V(G*2!["B1B=6YD;&4@/2`G<VET92<["GT*96QS:68@*"0Q(&5Q
M("=")RD@>PHD8G5N9&QE(#T@)V%L;"<["GT*96QS:68@*"0Q(&5Q("=Q)RD@
M>PHD<75I970@/2`Q.PI]"F5L<VEF("@D,2!E<2`G3"<I('L*;W!E;B`D;&]G
M9F@L("(^/B(L("0R(&]R(&1I92`B6%A8.B!#86YN;W0@;W!E;B!L;V<Z("0A
M(CL*?0IE;'-I9B`H)#$@97$@)U0G*2!["B1C86-H95]N86UE(#T@)#(["GT*
M<VAI9G0H0$%21U8I.PII9B`H;7D@)&-M9"`]("1D:7-T7V-M9'LD,7TI('L*
M9&5L971E("1%3E9[)U!!4E]414U0)WT["FEN:71?:6YC*"D["G)E<75I<F4@
M4$%2.CI$:7-T.PHF>R)005(Z.D1I<W0Z.B1C;60B?2@I('5N;&5S<R!`05)'
M5CL*)GLB4$%2.CI$:7-T.CHD8VUD(GTH)%\I(&9O<B!`05)'5CL*97AI=#L*
M?0I]"G5N<VAI9G0@0$E.0RP@0&%D9%]T;U]I;F,["GT*?0II9B`H)&]U="D@
M>PI["G)E<75I<F4@24\Z.D9I;&4["G)E<75I<F4@07)C:&EV93HZ6FEP.PI]
M"FUY("1P87(@/2!S:&EF="A`05)'5BD["FUY("1Z:7`["FEF("AD969I;F5D
M("1P87(I('L*07)C:&EV93HZ6FEP.CIS971#:'5N:U-I>F4H,3(X*C$P,C0I
M.PIO<&5N(&UY("1F:"P@)SPG+"`D<&%R(&]R(&1I92`B0V%N;F]T(&9I;F0@
M)R1P87(G.B`D(2(["F)I;FUO9&4H)&9H*3L*8FQE<W,H)&9H+"`G24\Z.D9I
M;&4G*3L*)'II<"`]($%R8VAI=F4Z.EII<"T^;F5W.PHH("1Z:7`M/G)E861&
M<F]M1FEL94AA;F1L92@D9F@L("1P87(I(#T]($%R8VAI=F4Z.EII<#HZ05I?
M3TLH*2`I"F]R(&1I92`B4F5A9"`G)'!A<B<@97)R;W(Z("0A(CL*?0IM>2`E
M96YV(#T@9&\@>PII9B`H)'II<"!A;F0@;7D@)&UE=&$@/2`D>FEP+3YC;VYT
M96YT<R@G345402YY;6PG*2D@>PHD;65T82`]?B!S+RXJ7G!A<CHD+R]M<SL*
M)&UE=&$@/7X@<R]>7%,N*B\O;7,["B1M971A(#U^("]>("`H6UXZ72LI.B`H
M+BLI)"]M9SL*?0I].PIL;V-A;"`D+R`](%PT.PII9B`H9&5F:6YE9"`D<&%R
M*2!["F]P96X@4$%2+"`G/"<L("1P87(@;W(@9&EE("(D(3H@)'!A<B(["F)I
M;FUO9&4H4$%2*3L*9&EE("(D<&%R(&ES(&YO="!A(%!!4B!F:6QE(B!U;FQE
M<W,@/%!!4CX@97$@(E!+7#`P,UPP,#0B.PI]"D-R96%T95!A=&@H)&]U="D@
M.PIM>2`D9F@@/2!)3SHZ1FEL92T^;F5W*`HD;W5T+`I)3SHZ1FEL93HZ3U]#
M4D5!5"@I('P@24\Z.D9I;&4Z.D]?5U)/3DQ9*"D@?"!)3SHZ1FEL93HZ3U]4
M4E5.0R@I+`HP-S<W+`HI(&]R(&1I92`D(3L*8FEN;6]D92@D9F@I.PHD+R`]
M("AD969I;F5D("1D871A7W!O<RD@/R!<)&1A=&%?<&]S(#H@=6YD968["G-E
M96L@7T9(+"`P+"`P.PIM>2`D;&]A9&5R(#T@<V-A;&%R(#Q?1D@^.PII9B`H
M(21%3E9[4$%27U9%4D)!5$E-?2!A;F0@)&QO861E<B`]?B`O7B@_.B,A?%Q`
M<F5M*2\I('L*<F5Q=6ER92!005(Z.D9I;'1E<CHZ4&]D4W1R:7`["E!!4CHZ
M1FEL=&5R.CI0;V13=')I<"T^;F5W+3YA<'!L>2A<)&QO861E<BP@)#`I"GT*
M9F]R96%C:"!M>2`D:V5Y("AS;W)T(&ME>7,@)65N=BD@>PIM>2`D=F%L(#T@
M)&5N=GLD:V5Y?2!O<B!N97AT.PHD=F%L(#T@979A;"`D=F%L(&EF("1V86P@
M/7X@+UY;)R)=+SL*;7D@)&UA9VEC(#T@(E]?14Y67U!!4E\B("X@=6,H)&ME
M>2D@+B`B7U\B.PIM>2`D<V5T(#T@(E!!4E\B("X@=6,H)&ME>2D@+B`B/21V
M86PB.PHD;&]A9&5R(#U^('-[)&UA9VEC*"`K*7U["B1M86=I8R`N("1S970@
M+B`H)R`G('@@*&QE;F=T:"@D,2D@+2!L96YG=&@H)'-E="DI*0I]96<["GT*
M)&9H+3YP<FEN="@D;&]A9&5R*3L*)"\@/2!U;F1E9CL*:68@*"1B=6YD;&4I
M('L*<F5Q=6ER92!005(Z.DAE879Y.PI005(Z.DAE879Y.CI?:6YI=%]D>6YA
M;&]A9&5R*"D["FEN:71?:6YC*"D["G)E<75I<F5?;6]D=6QE<R@I.PIM>2!`
M:6YC(#T@9W)E<"![("$O0E-$4$%.+R!]"F=R97`@>PHH)&)U;F1L92!N92`G
M<VET92<I(&]R"B@D7R!N92`D0V]N9FEG.CI#;VYF:6=[87)C:&QI8F5X<'T@
M86YD"B1?(&YE("1#;VYF:6<Z.D-O;F9I9WMP<FEV;&EB97AP?2D["GT@0$E.
M0SL*;7D@)69I;&5S.PHD9FEL97-[)%]]*RL@9F]R($!$>6YA3&]A9&5R.CID
M;%]S:&%R961?;V)J96-T<RP@=F%L=65S("5)3D,["FUY("1L:6)?97AT(#T@
M)$-O;F9I9SHZ0V]N9FEG>VQI8E]E>'1].PIM>2`E=W)I='1E;CL*9F]R96%C
M:"`H<V]R="!K97ES("5F:6QE<RD@>PIM>2`H)&YA;64L("1F:6QE*3L*9F]R
M96%C:"!M>2`D9&ER("A`:6YC*2!["FEF("@D;F%M92`]("1005(Z.DAE879Y
M.CI&=6QL0V%C:&5[)%]]*2!["B1F:6QE(#T@)%\["FQA<W0["GT*96QS:68@
M*"]>*%Q1)&1I<EQ%7"\H+BI;7D-C72DI7%HO:2D@>PHH)&9I;&4L("1N86UE
M*2`]("@D,2P@)#(I.PIL87-T.PI]"F5L<VEF("AM(5XO;&]A9&5R+UM>+UTK
M+R@N*EM>0V-=*5Q:(2D@>PII9B`H;7D@)')E9B`]("1005(Z.DAE879Y.CI-
M;V1U;&5#86-H97LD,7TI('L**"1F:6QE+"`D;F%M92D@/2`H)')E9BP@)#$I
M.PIL87-T.PI]"F5L<VEF("@M9B`B)&1I<B\D,2(I('L**"1F:6QE+"`D;F%M
M92D@/2`H(B1D:7(O)#$B+"`D,2D["FQA<W0["GT*?0I]"FYE>'0@=6YL97-S
M(&1E9FEN960@)&YA;64@86YD(&YO="`D=W)I='1E;GLD;F%M97TK*SL*;F5X
M="!I9B`A<F5F*"1F:6QE*2!A;F0@)&9I;&4@/7X@+UPN7%$D;&EB7V5X=%Q%
M)"\["F]U=',H(&IO:6X@(B(L"G%Q*%!A8VMI;F<@(BDL(')E9B`D9FEL92`_
M("1F:6QE+3Y[;F%M97T@.B`D9FEL92P*<7$H(BXN+BD**3L*;7D@)&-O;G1E
M;G0["FEF("AR968H)&9I;&4I*2!["B1C;VYT96YT(#T@)&9I;&4M/GMB=69]
M.PI]"F5L<V4@>PIO<&5N($9)3$4L("<\)RP@)&9I;&4@;W(@9&EE(")#86XG
M="!O<&5N("1F:6QE.B`D(2(["F)I;FUO9&4H1DE,12D["B1C;VYT96YT(#T@
M/$9)3$4^.PIC;&]S92!&24Q%.PI005(Z.D9I;'1E<CHZ4&]D4W1R:7`M/FYE
M=RT^87!P;'DH7"1C;VYT96YT+"`D9FEL92D*:68@(21%3E9[4$%27U9%4D)!
M5$E-?2!A;F0@)&YA;64@/7X@+UPN*#\Z<&U\:7A\86PI)"]I.PI005(Z.D9I
M;'1E<CHZ4&%T8VA#;VYT96YT+3YN97<M/F%P<&QY*%PD8V]N=&5N="P@)&9I
M;&4L("1N86UE*3L*?0IO=71S*'%Q*%=R:71T96X@87,@(B1N86UE(BDI.PHD
M9F@M/G!R:6YT*")&24Q%(BD["B1F:"T^<')I;G0H<&%C:R@G3B<L(&QE;F=T
M:"@D;F%M92D@*R`Y*2D["B1F:"T^<')I;G0H<W!R:6YT9B@*(B4P.'@O)7,B
M+"!!<F-H:79E.CI::7`Z.F-O;7!U=&5#4D,S,B@D8V]N=&5N="DL("1N86UE
M"BDI.PHD9F@M/G!R:6YT*'!A8VLH)TXG+"!L96YG=&@H)&-O;G1E;G0I*2D[
M"B1F:"T^<')I;G0H)&-O;G1E;G0I.PI]"GT*)'II<"T^=W)I=&54;T9I;&5(
M86YD;&4H)&9H*2!I9B`D>FEP.PHD8V%C:&5?;F%M92`]('-U8G-T<B`D8V%C
M:&5?;F%M92P@,"P@-#`["FEF("@A)&-A8VAE7VYA;64@86YD(&UY("1M=&EM
M92`]("AS=&%T*"1O=70I*5LY72D@>PIM>2`D8W1X(#T@979A;"![(')E<75I
M<F4@1&EG97-T.CI32$$[($1I9V5S=#HZ4TA!+3YN97<H,2D@?0I\?"!E=F%L
M('L@<F5Q=6ER92!$:6=E<W0Z.E-(03$[($1I9V5S=#HZ4TA!,2T^;F5W('T*
M?'P@979A;"![(')E<75I<F4@1&EG97-T.CI-1#4[($1I9V5S=#HZ340U+3YN
M97<@?3L*;7D@)'-H85]V97)S:6]N(#T@979A;"![("1$:6=E<W0Z.E-(03HZ
M5D524TE/3B!]('Q\(#`["FEF("@D<VAA7W9E<G-I;VX@97$@)S4N,S@G(&]R
M("1S:&%?=F5R<VEO;B!E<2`G-2XS.2<I('L*)&-T>"T^861D9FEL92@D;W5T
M+"`B8B(I(&EF("@D8W1X*3L*?0IE;'-E('L*:68@*"1C='@@86YD(&]P96XH
M;7D@)&9H+"`B/"1O=70B*2D@>PIB:6YM;V1E*"1F:"D["B1C='@M/F%D9&9I
M;&4H)&9H*3L*8VQO<V4H)&9H*3L*?0I]"B1C86-H95]N86UE(#T@)&-T>"`_
M("1C='@M/FAE>&1I9V5S="`Z("1M=&EM93L*?0HD8V%C:&5?;F%M92`N/2`B
M7#`B('@@*#0Q("T@;&5N9W1H("1C86-H95]N86UE*3L*)&-A8VAE7VYA;64@
M+CT@(D-!0TA%(CL*)&9H+3YP<FEN="@D8V%C:&5?;F%M92D["B1F:"T^<')I
M;G0H<&%C:R@G3B<L("1F:"T^=&5L;"`M(&QE;F=T:"@D;&]A9&5R*2DI.PHD
M9F@M/G!R:6YT*")<;E!!4BYP;5QN(BD["B1F:"T^8VQO<V4["F-H;6]D(#`W
M-34L("1O=70["F5X:70["GT*>PIL87-T('5N;&5S<R!D969I;F5D("1S=&%R
M=%]P;W,["E]F:7A?<')O9VYA;64H*3L*<F5Q=6ER92!005(["E!!4CHZ2&5A
M=GDZ.E]I;FET7V1Y;F%L;V%D97(H*3L*>PIR97%U:7)E($9I;&4Z.D9I;F0[
M"G)E<75I<F4@07)C:&EV93HZ6FEP.PI]"FUY("1Z:7`@/2!!<F-H:79E.CI:
M:7`M/FYE=SL*;7D@)&9H(#T@24\Z.D9I;&4M/FYE=SL*)&9H+3YF9&]P96XH
M9FEL96YO*%]&2"DL("=R)RD@;W(@9&EE("(D(3H@)$`B.PHD>FEP+3YR96%D
M1G)O;49I;&5(86YD;&4H)&9H+"`D<')O9VYA;64I(#T]($%R8VAI=F4Z.EII
M<#HZ05I?3TLH*2!O<B!D:64@(B0A.B`D0"(["G!U<V@@0%!!4CHZ3&EB0V%C
M:&4L("1Z:7`["B1005(Z.DQI8D-A8VAE>R1P<F]G;F%M97T@/2`D>FEP.PHD
M<75I970@/2`A)$5.5GM005)?1$5"54=].PIO=71S*'%Q*%PD14Y6>U!!4E]4
M14U0?2`]("(D14Y6>U!!4E]414U0?2(I*3L*:68@*&1E9FEN960@)$5.5GM0
M05)?5$5-4'TI('L@(R!S:&]U;&0@8F4@<V5T(&%T('1H:7,@<&]I;G0A"F9O
M<F5A8V@@;7D@)&UE;6)E<B`H("1Z:7`M/FUE;6)E<G,@*2!["FYE>'0@:68@
M)&UE;6)E<BT^:7-$:7)E8W1O<GD["FUY("1M96UB97)?;F%M92`]("1M96UB
M97(M/F9I;&5.86UE.PIN97AT('5N;&5S<R`D;65M8F5R7VYA;64@/7X@;7L*
M7@HO/W-H;&EB+PHH/SHD0V]N9FEG.CI#;VYF:6=[=F5R<VEO;GTO*3\**#\Z
M)$-O;F9I9SHZ0V]N9FEG>V%R8VAN86UE?2\I/PHH6UXO72LI"B0*?7@["FUY
M("1E>'1R86-T7VYA;64@/2`D,3L*;7D@)&1E<W1?;F%M92`]($9I;&4Z.E-P
M96,M/F-A=&9I;&4H)$5.5GM005)?5$5-4'TL("1E>'1R86-T7VYA;64I.PII
M9B`H+68@)&1E<W1?;F%M92`F)B`M<R!?(#T]("1M96UB97(M/G5N8V]M<')E
M<W-E9%-I>F4H*2D@>PIO=71S*'%Q*%-K:7!P:6YG("(D;65M8F5R7VYA;64B
M('-I;F-E(&ET(&%L<F5A9'D@97AI<W1S(&%T("(D9&5S=%]N86UE(BDI.PI]
M(&5L<V4@>PIO=71S*'%Q*$5X=')A8W1I;F<@(B1M96UB97)?;F%M92(@=&\@
M(B1D97-T7VYA;64B*2D["B1M96UB97(M/F5X=')A8W14;T9I;&5.86UE9"@D
M9&5S=%]N86UE*3L*8VAM;V0H,#4U-2P@)&1E<W1?;F%M92D@:68@)%Y/(&5Q
M(")H<'5X(CL*?0I]"GT*?0IU;FQE<W,@*"1005(Z.DQI8D-A8VAE>R1P<F]G
M;F%M97TI('L*9&EE(#P\("(N(B!U;FQE<W,@0$%21U8["E5S86=E.B`D,"!;
M("U!;&EB+G!A<B!=(%L@+4ED:7(@72!;("U-;6]D=6QE(%T@6R!S<F,N<&%R
M(%T@6R!P<F]G<F%M+G!L(%T*)#`@6R`M0GPM8B!=(%LM3V]U=&9I;&5=('-R
M8RYP87(*+@HD14Y6>U!!4E]04D]'3D%-17T@/2`D<')O9VYA;64@/2`D,"`]
M('-H:69T*$!!4D=6*3L*?0IS=6(@0W)E871E4&%T:"!["FUY("@D;F%M92D@
M/2!`7SL*<F5Q=6ER92!&:6QE.CI"87-E;F%M93L*;7D@*"1B87-E;F%M92P@
M)'!A=&@L("1E>'0I(#T@1FEL93HZ0F%S96YA;64Z.F9I;&5P87)S92@D;F%M
M92P@*"=<+BXJ)RDI.PIR97%U:7)E($9I;&4Z.E!A=&@["D9I;&4Z.E!A=&@Z
M.FUK<&%T:"@D<&%T:"D@=6YL97-S*"UE("1P871H*3L@(R!M:W!A=&@@9&EE
M<R!W:71H(&5R<F]R"GT*<W5B(')E<75I<F5?;6]D=6QE<R!["G)E<75I<F4@
M;&EB.PIR97%U:7)E($1Y;F%,;V%D97(["G)E<75I<F4@:6YT96=E<CL*<F5Q
M=6ER92!S=')I8W0["G)E<75I<F4@=V%R;FEN9W,["G)E<75I<F4@=F%R<SL*
M<F5Q=6ER92!#87)P.PIR97%U:7)E($-A<G`Z.DAE879Y.PIR97%U:7)E($5R
M<FYO.PIR97%U:7)E($5X<&]R=&5R.CI(96%V>3L*<F5Q=6ER92!%>'!O<G1E
M<CL*<F5Q=6ER92!&8VYT;#L*<F5Q=6ER92!&:6QE.CI496UP.PIR97%U:7)E
M($9I;&4Z.E-P96,["G)E<75I<F4@6%-,;V%D97(["G)E<75I<F4@0V]N9FEG
M.PIR97%U:7)E($E/.CI(86YD;&4["G)E<75I<F4@24\Z.D9I;&4["G)E<75I
M<F4@0V]M<')E<W,Z.EIL:6(["G)E<75I<F4@07)C:&EV93HZ6FEP.PIR97%U
M:7)E(%!!4CL*<F5Q=6ER92!005(Z.DAE879Y.PIR97%U:7)E(%!!4CHZ1&ES
M=#L*<F5Q=6ER92!005(Z.D9I;'1E<CHZ4&]D4W1R:7`["G)E<75I<F4@4$%2
M.CI&:6QT97(Z.E!A=&-H0V]N=&5N=#L*<F5Q=6ER92!A='1R:6)U=&5S.PIE
M=F%L('L@<F5Q=6ER92!#=V0@?3L*979A;"![(')E<75I<F4@5VEN,S(@?3L*
M979A;"![(')E<75I<F4@4V-A;&%R.CI5=&EL('T["F5V86P@>R!R97%U:7)E
M($%R8VAI=F4Z.E5N>FEP.CI"=7)S="!].PIE=F%L('L@<F5Q=6ER92!4:64Z
M.DAA<V@Z.DYA;65D0V%P='5R92!].PIE=F%L('L@<F5Q=6ER92!097)L24\[
M(')E<75I<F4@4&5R;$E/.CIS8V%L87(@?3L*979A;"![(')E<75I<F4@=71F
M."!].PI]"G-U8B!?<V5T7W!A<E]T96UP('L*:68@*&1E9FEN960@)$5.5GM0
M05)?5$5-4'T@86YD("1%3E9[4$%27U1%35!](#U^("\H+BLI+RD@>PHD<&%R
M7W1E;7`@/2`D,3L*<F5T=7)N.PI]"F9O<F5A8V@@;7D@)'!A=&@@*`HH;6%P
M("1%3E9[)%]]+"!Q=R@@4$%27U1-4$1)4B!435!$25(@5$5-4$1)4B!414U0
M(%1-4"`I*2P*<7<H($,Z7%Q414U0("]T;7`@+B`I"BD@>PIN97AT('5N;&5S
M<R!D969I;F5D("1P871H(&%N9"`M9"`D<&%T:"!A;F0@+7<@)'!A=&@["FUY
M("1U<V5R;F%M93L*;7D@)'!W=6ED.PIE=F%L('LH)'!W=6ED*2`](&=E='!W
M=6ED*"0^*2!I9B!D969I;F5D("0^.WT["FEF("@@9&5F:6YE9"@F5VEN,S(Z
M.DQO9VEN3F%M92D@*2!["B1U<V5R;F%M92`]("97:6XS,CHZ3&]G:6Y.86UE
M.PI]"F5L<VEF("AD969I;F5D("1P=W5I9"D@>PHD=7-E<FYA;64@/2`D<'=U
M:60["GT*96QS92!["B1U<V5R;F%M92`]("1%3E9[55-%4DY!345]('Q\("1%
M3E9[55-%4GT@?'P@)U-94U1%32<["GT*)'5S97)N86UE(#U^(',O7%<O7R]G
M.PIM>2`D<W1M<&1I<B`]("(D<&%T:"1#;VYF:6=[7V1E;&EM?7!A<BTB+G5N
M<&%C:R@B2"HB+"`D=7-E<FYA;64I.PIM:V1I<B`D<W1M<&1I<BP@,#<U-3L*
M:68@*"$D14Y6>U!!4E]#3$5!3GT@86YD(&UY("1M=&EM92`]("AS=&%T*"1P
M<F]G;F%M92DI6SE=*2!["F]P96X@*&UY("1F:"P@(CPB+B`D<')O9VYA;64I
M.PIS965K("1F:"P@+3$X+"`R.PIS>7-R96%D("1F:"P@;7D@)&)U9BP@-CL*
M:68@*"1B=68@97$@(EPP0T%#2$4B*2!["G-E96L@)&9H+"`M-3@L(#(["G-Y
M<W)E860@)&9H+"`D8G5F+"`T,3L*)&)U9B`]?B!S+UPP+R]G.PHD<W1M<&1I
M<B`N/2`B)$-O;F9I9WM?9&5L:6U]8V%C:&4M(B`N("1B=68["GT*96QS92![
M"FUY("1C='@@/2!E=F%L('L@<F5Q=6ER92!$:6=E<W0Z.E-(03L@1&EG97-T
M.CI32$$M/FYE=R@Q*2!]"GQ\(&5V86P@>R!R97%U:7)E($1I9V5S=#HZ4TA!
M,3L@1&EG97-T.CI32$$Q+3YN97<@?0I\?"!E=F%L('L@<F5Q=6ER92!$:6=E
M<W0Z.DU$-3L@1&EG97-T.CI-1#4M/FYE=R!].PIM>2`D<VAA7W9E<G-I;VX@
M/2!E=F%L('L@)$1I9V5S=#HZ4TA!.CI615)324].('T@?'P@,#L*:68@*"1S
M:&%?=F5R<VEO;B!E<2`G-2XS."<@;W(@)'-H85]V97)S:6]N(&5Q("<U+C,Y
M)RD@>PHD8W1X+3YA9&1F:6QE*"1P<F]G;F%M92P@(F(B*2!I9B`H)&-T>"D[
M"GT*96QS92!["FEF("@D8W1X(&%N9"!O<&5N*&UY("1F:"P@(CPD<')O9VYA
M;64B*2D@>PIB:6YM;V1E*"1F:"D["B1C='@M/F%D9&9I;&4H)&9H*3L*8VQO
M<V4H)&9H*3L*?0I]"B1S=&UP9&ER("X]("(D0V]N9FEG>U]D96QI;7UC86-H
M92TB("X@*"`D8W1X(#\@)&-T>"T^:&5X9&EG97-T(#H@)&UT:6UE("D["GT*
M8VQO<V4H)&9H*3L*?0IE;'-E('L*)$5.5GM005)?0TQ%04Y](#T@,3L*)'-T
M;7!D:7(@+CT@(B1#;VYF:6=[7V1E;&EM?71E;7`M)"0B.PI]"B1%3E9[4$%2
M7U1%35!](#T@)'-T;7!D:7(["FUK9&ER("1S=&UP9&ER+"`P-S4U.PIL87-T
M.PI]"B1P87)?=&5M<"`]("0Q(&EF("1%3E9[4$%27U1%35!](&%N9"`D14Y6
M>U!!4E]414U0?2`]?B`O*"XK*2\["GT*<W5B(%]T96UP9FEL92!["FUY("@D
M;F%M92P@)&-O;G1E;G1S+"`D;6]D92D@/2!`7SL*;7D@)&9U;&QN86UE(#T@
M(B1P87)?=&5M<"\D;F%M92(["G5N;&5S<R`H+64@)&9U;&QN86UE*2!["FUY
M("1T96UP;F%M92`]("(D9G5L;&YA;64N)"0B.PIO<&5N(&UY("1F:"P@)SXG
M+"`D=&5M<&YA;64@;W(@9&EE(")C86XG="!W<FET92`D=&5M<&YA;64Z("0A
M(CL*8FEN;6]D92`D9F@["G!R:6YT("1F:"`D8V]N=&5N=',["F-L;W-E("1F
M:#L*8VAM;V0@)&UO9&4L("1T96UP;F%M92!I9B!D969I;F5D("1M;V1E.PIR
M96YA;64H)'1E;7!N86UE+"`D9G5L;&YA;64I(&]R('5N;&EN:R@D=&5M<&YA
M;64I.PI]"G)E='5R;B`D9G5L;&YA;64["GT*<W5B(%]S971?<')O9VYA;64@
M>PII9B`H9&5F:6YE9"`D14Y6>U!!4E]04D]'3D%-17T@86YD("1%3E9[4$%2
M7U!23T=.04U%?2`]?B`O*"XK*2\I('L*)'!R;V=N86UE(#T@)#$["GT*)'!R
M;V=N86UE('Q\/2`D,#L*:68@*"1%3E9[4$%27U1%35!](&%N9"!I;F1E>"@D
M<')O9VYA;64L("1%3E9[4$%27U1%35!]*2`^/2`P*2!["B1P<F]G;F%M92`]
M('-U8G-T<B@D<')O9VYA;64L(')I;F1E>"@D<')O9VYA;64L("1#;VYF:6=[
M7V1E;&EM?2D@*R`Q*3L*?0II9B`H(21%3E9[4$%27U!23T=.04U%?2!O<B!I
M;F1E>"@D<')O9VYA;64L("1#;VYF:6=[7V1E;&EM?2D@/CT@,"D@>PII9B`H
M;W!E;B!M>2`D9F@L("<\)RP@)'!R;V=N86UE*2!["G)E='5R;B!I9B`M<R`D
M9F@["GT*:68@*"US("(D<')O9VYA;64D0V]N9FEG>U]E>&5](BD@>PHD<')O
M9VYA;64@+CT@)$-O;F9I9WM?97AE?3L*<F5T=7)N.PI]"GT*9F]R96%C:"!M
M>2`D9&ER("AS<&QI="`O7%$D0V]N9FEG>W!A=&A?<V5P?5Q%+RP@)$5.5GM0
M051(?2D@>PIN97AT(&EF(&5X:7-T<R`D14Y6>U!!4E]414U0?2!A;F0@)&1I
M<B!E<2`D14Y6>U!!4E]414U0?3L*)&1I<B`]?B!S+UQ1)$-O;F9I9WM?9&5L
M:6U]7$4D+R\["B@H)'!R;V=N86UE(#T@(B1D:7(D0V]N9FEG>U]D96QI;7TD
M<')O9VYA;64D0V]N9FEG>U]E>&5](BDL(&QA<W0I"FEF("US("(D9&ER)$-O
M;F9I9WM?9&5L:6U])'!R;V=N86UE)$-O;F9I9WM?97AE?2(["B@H)'!R;V=N
M86UE(#T@(B1D:7(D0V]N9FEG>U]D96QI;7TD<')O9VYA;64B*2P@;&%S="D*
M:68@+7,@(B1D:7(D0V]N9FEG>U]D96QI;7TD<')O9VYA;64B.PI]"GT*<W5B
M(%]F:7A?<')O9VYA;64@>PHD,"`]("1P<F]G;F%M92!\?#T@)$5.5GM005)?
M4%)/1TY!345].PII9B`H:6YD97@H)'!R;V=N86UE+"`D0V]N9FEG>U]D96QI
M;7TI(#P@,"D@>PHD<')O9VYA;64@/2`B+B1#;VYF:6=[7V1E;&EM?21P<F]G
M;F%M92(["GT*;7D@)'!W9"`]("AD969I;F5D("9#=V0Z.F=E=&-W9"D@/R!#
M=V0Z.F=E=&-W9"@I"CH@*"AD969I;F5D("97:6XS,CHZ1V5T0W=D*2`_(%=I
M;C,R.CI'971#=V0H*2`Z(&!P=V1@*3L*8VAO;7`H)'!W9"D["B1P<F]G;F%M
M92`]?B!S+UXH/SU<+EPN/UQ1)$-O;F9I9WM?9&5L:6U]7$4I+R1P=V0D0V]N
M9FEG>U]D96QI;7TO.PHD14Y6>U!!4E]04D]'3D%-17T@/2`D<')O9VYA;64[
M"GT*<W5B(%]P87)?:6YI=%]E;G8@>PII9B`H("1%3E9[4$%27TE.251)04Q)
M6D5$?2LK(#T](#$@*2!["G)E='5R;CL*?2!E;'-E('L*)$5.5GM005)?24Y)
M5$E!3$E:141](#T@,CL*?0IF;W(@*'%W*"!34$%73D5$(%1%35`@0TQ%04X@
M1$5"54<@0T%#2$4@4%)/1TY!344@05)'0R!!4D=67S`@*2`I('L*9&5L971E
M("1%3E9[)U!!4E\G+B1??3L*?0IF;W(@*'%W+R!435!$25(@5$5-4"!#3$5!
M3B!$14)51R`O*2!["B1%3E9[)U!!4E\G+B1??2`]("1%3E9[)U!!4E]'3$]"
M04Q?)RXD7WT@:68@97AI<W1S("1%3E9[)U!!4E]'3$]"04Q?)RXD7WT["GT*
M;7D@)'!A<E]C;&5A;B`](")?7T5.5E]005)?0TQ%04Y?7R`@("`@("`@("`@
M("`@("(["FEF("@D14Y6>U!!4E]414U0?2D@>PID96QE=&4@)$5.5GM005)?
M0TQ%04Y].PI]"F5L<VEF("@A97AI<W1S("1%3E9[4$%27T=,3T)!3%]#3$5!
M3GTI('L*;7D@)'9A;'5E(#T@<W5B<W1R*"1P87)?8VQE86XL(#$R("L@;&5N
M9W1H*")#3$5!3B(I*3L*)$5.5GM005)?0TQ%04Y](#T@)#$@:68@)'9A;'5E
M(#U^("]>4$%27T-,14%./2A<4RLI+SL*?0I]"G-U8B!O=71S('L*<F5T=7)N
M(&EF("1Q=6EE=#L*:68@*"1L;V=F:"D@>PIP<FEN="`D;&]G9F@@(D!?7&XB
M.PI]"F5L<V4@>PIP<FEN="`B0%]<;B(["GT*?0IS=6(@:6YI=%]I;F,@>PIR
M97%U:7)E($-O;F9I9SL*<'5S:"!`24Y#+"!G<F5P(&1E9FEN960L(&UA<"`D
M0V]N9FEG.CI#;VYF:6=[)%]]+"!Q=R@*87)C:&QI8F5X<"!P<FEV;&EB97AP
M('-I=&5A<F-H97AP('-I=&5L:6)E>'`*=F5N9&]R87)C:&5X<"!V96YD;W)L
M:6)E>'`**3L*?0IP86-K86=E(&UA:6X["G)E<75I<F4@4$%2.PIU;G-H:69T
M($!)3D,L(%PF4$%2.CIF:6YD7W!A<CL*4$%2+3YI;7!O<G0H0'!A<E]A<F=S
M*3L*9&EE('%Q*'!A<BYP;#H@0V%N)W0@;W!E;B!P97)L('-C<FEP="`B)'!R
M;V=N86UE(CH@3F\@<W5C:"!F:6QE(&]R(&1I<F5C=&]R>5QN*0IU;FQE<W,@
M+64@)'!R;V=N86UE.PID;R`D<')O9VYA;64["D-/4D4Z.F5X:70H)#$I(&EF
M("@D0"`]?B]>7U1+7T58251?7"@H7&0K*5PI+RD["F1I92`D0"!I9B`D0#L*
M?3L*)#HZ7U]%4E)/4B`]("1`(&EF("1`.PI]"D-/4D4Z.F5X:70H)#$I(&EF
M("@D.CI?7T524D]2(#U^+UY?5$M?15A)5%]<*"A<9"LI7"DO*3L*9&EE("0Z
M.E]?15)23U(@:68@)#HZ7U]%4E)/4CL*,3L*7U]%3D1?7PH``````%]?14Y6
M7U!!4E]#3$5!3E]?("`@("`@("`@("`@("`@``````````!P97)L>'-I+F,`
M```!&P,[(%```!H````D@?__'%D``'R#__\\4```((7__W10```@G/__S%``
M`'2=__^\40``()[__QQ2``"4H/__I%(``"BB__\\4P``N*+__Y13``!$I/__
M%%0``("D__],5```V*3__Y14``#HI?__#%4``.RE__\L50``**C__[15``!8
MJ/__U%4``&BI__]$5@``.*O__Y16``#,J___[%8``/"K__\D5P``T*S__XQ7
M``",NO__)%@``'R^__^T6```%+___X19``"DO___]%D``*B___\46@``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````%```````
M```!>E(``7P!`1P-`P``````'````!P````X,________X0```````````<!
M```````4``````````-Z4@`!?`$!'`P#``````!4````'````*0T________
M`!<`````````!!`````.L`4$&````($"EP28!ID(!,`6```*P00$````UP0$
M````V`0$````V00$````#@`$!`````L`````[````'0```!,2________U0!
M``````````0$````#D`$(````($"EP28!ID(F@J;#)P.G1`$;`````K!!`@`
M``#7!`0```#8!`0```#9!`0```#:!`0```#;!`0```#<!`0```#=!`0````.
M``0$````"P0T````"L$$$````-<$!````-@$!````-D$!````-H$!````-L$
M!````-P$!````-T$!`````X`!`0````+!`0````*P00,````UP0$````V`0$
M````V00$````V@0$````VP0$````W`0$````W00$````#@`$!`````L`7```
M`&0!``"P2________ZP```````````0$````#D`$!````)H*!!P```"7!)@&
MF0B!`@1L````"L$$!````-<$!````-@$!````-D$!````-H$!`````X`!`0`
M```+A````,0!``#\2________W0"``````````0$````#F`$!````)D(!"P`
M``"7!)@&@0*:"IL,G`Z=$)X2GQ0$)`$```K!!`0```#7!`0```#8!`0```#9
M!`0```#:!`0```#;!`0```#<!`0```#=!`0```#>!`0```#?!`0````.``0$
M````"Y0```!,`@``Z$W_______^4`0`````````$!`````[P`00$````F0H$
M-````($"E@27!I@(F@R;#IP0G1*>%)\6!"0````*P00$````U@0$````UP0$
M````V`0$````V00$````V@0$````VP0$````W`0$````W00$````W@0$````
MWP0$````#@`$!`````L`````````5````.0"``#D3O_______Y``````````
M``0$````#K`!!`0```"7!`04````F`8$$````($"!%`````*P00$````UP0$
M````V`0$````#@`$!`````L``'P````\`P``'$________^,`0`````````$
M!`````Y0!`P```"7!)@&!"@````.T""9")H*@0*;#)P.!,`````*#E`$!```
M`,$$!````-<$!````-@$!````-D$!````-H$!````-L$!````-P$!`````X`
M!`0````+````````-````+P#```H4/_______SP```````````00````#A`$
M!````($"!`@```#!!!P````.``````!$````]`,``"Q0________6```````
M````!`0````.$`0$````EP0$$````($"!!0```#!!`0```#7!"0````.````
M``````!T````/`0``#Q0________$`$`````````!`0````.4`0$````F0@$
M*`````[00($"EP28!IH*FPP$M`````H.4`0$````P00$````UP0$````V`0$
M````V00$````V@0$````VP0$````#@`$!`````L````````<````M`0``-10
M________!````````````````````(0```#4!```N%#_______\\`@``````
M```$!`````[0`00(````G`X$,`````[0(9<$F`:9")T0@0*:"IL,!&@````*
M#M`!!`0```#!!`0```#7!`0```#8!`0```#9!`0```#:!`0```#;!`0```#<
M!`0```#=!`0````.``0$````"P`````<````7`4``&Q2________,```````
M`````````````&P```!\!0``?%+_______\0`0`````````$"`````X0!`@`
M``"7!($"!&`````*P00$````UP0$````#@`$!`````L$8`````K!!`0```#7
M!`P````.``0$````"P0$````P00$````UP0(````#@!,````[`4``!Q3____
M____T`$`````````!`0````.8`0,````F`8$2````($"EP0$$`$```K!!`0`
M``#7!`0```#8!`0````.``0$````"U0````\!@``G%3_______^4````````
M```$!`````XP!`0```"7!`00````F`8$%````($"!!@````*P00$````UP0$
M````V`0$````#@`$!`````L````T````E`8``-A4________)```````````
M!`0````.$`0$````@0($%````,$$!`````X``````&0```#,!@``Q%3_____
M___@```````````$!`````Y`!`0```"7!`04````F0@$&````($"F`::"@0X
M````"L$$!````-<$!````-@$!````-D$!````-H$!`````X`!`0````+````
ME````#0'```\5?_______[P-``````````0$````#L`#!#P````.P(,"F@R;
M#H$"E@27!I@(F0J<$)T2GA2?%@0(`P``"@[``P0$````P00$````U@0$````
MUP0$````V`0$````V00$````V@0$````VP0$````W`0$````W00$````W@0$
M````WP0$````#@`$!`````N,````S`<``&!B________\`,`````````!`0`
M```.@`$$+````($"EP:8")D*E@2:#)L.G!"=$IX4GQ8$J`(```K!!`0```#6
M!`0```#7!`0```#8!`0```#9!`0```#:!`0```#;!`0```#<!`0```#=!`0`
M``#>!`0```#?!`0````.``0$````"P````!D````7`@``,!E________F```
M````````!`0````.(`0,````EP28!H$"!&`````*P00$````UP0$````V`0$
M````#@`$!`````L$!````,$$!````-<$"````-@$!`````X``````&0```#$
M"````"C_______]4`@`````````$!`````Y@!`0```"8!@0\````@0*7!)D(
MF@J;#`1L`0``"L$$!````-<$!````-@$!````-D$!````-H$!````-L$!```
M``X`!`0````+;````"P)``"(9?_______Y````````````0$````#D`$"```
M`)<$F0@$*````($"F`::"IL,G`X$/````,$$!````-<$!````-@$!````-D$
M!````-H$!````-L$!````-P$!`````X``````````!P```"<"0``J&7_____
M__\$````````````````````&````+P)``",9?_______Q0`````````````
M``````"$*````````!PH`````````0`````````!``````````$`````````
MK0$````````!`````````+@!`````````0````````#"`0````````$`````
M````$0(````````!`````````&H#`````````0````````"$`P```````!D`
M````````L/T````````;``````````@`````````&@````````"X_0``````
M`!P`````````"``````````$`````````)`"````````]?[_;P````#`!0``
M``````4`````````0!`````````&`````````(`&````````"@````````#.
M!`````````L`````````&``````````5`````````````````````P``````
M``!```$```````(`````````H`4````````4``````````<`````````%P``
M```````8&P````````<`````````4!8````````(`````````&@*````````
M"0`````````8`````````!X`````````"`````````#[__]O``````$```@`
M````_O__;P````#@%0```````/___V\``````P````````#P__]O``````X5
M````````^?__;P`````,````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````H&0````````P9@```````#AF````````0&8```````!(
M9@``````````````````_____P`````09P```````/__________````````
M``#`(````````,`@````````P"````````#`(````````,`@````````P"``
M``````#`(````````,`@````````P"````````#`(````````,`@````````
MP"````````#`(````````,`@````````P"````````#`(````````,`@````
M````P"````````#`(````````,`@````````P"````````#`(````````,`@
M````````P"````````#`(````````,`@````````P"````````#`(```````
M`,`@````````P"````````#`(````````,`@````````P"````````#`(```
M`````,`@````````P"````````#`(````````,`@````````P"````````#`
M(````````,`@````````P"````````#`(````````,`@````````P"``````
M``#`(````````,`@````````P"````````#`(````````,`@````````P"``
M``````#`(````````,`@````````P"````````#`(````````,`@````````
MP"````````#`(````````,`@````````P"````````#`_0``````````````
M````(&,`````````````````````````````````````````````````````
M``````````````````````````````````````````````````"08@``````
M`````````````````````````````````*`D````````N`(!``````!'0T,Z
M("A,;V]N9VYI>"`X+C,N,"TV+FQN9"YV96,N,S`I(#@N,RXP```N<VAS=')T
M86(`+FEN=&5R<``N;F]T92Y!0DDM=&%G`"YN;W1E+F=N=2YB=6EL9"UI9``N
M9VYU+FAA<V@`+F1Y;G-Y;0`N9'EN<W1R`"YG;G4N=F5R<VEO;@`N9VYU+G9E
M<G-I;VY?<@`N<F5L82YD>6X`+G)E;&$N<&QT`"YT97AT`"YR;V1A=&$`+F5H
M7V9R86UE7VAD<@`N96A?9G)A;64`+FEN:71?87)R87D`+F9I;FE?87)R87D`
M+F1Y;F%M:6,`+F1A=&$`+F=O=``N<V1A=&$`+F)S<P`N8V]M;65N=```````
M````````````````````````````````````````````````````````````
M```````````````````````+`````0````(`````````.`(````````X`@``
M``````\````````````````````!````````````````````$P````<````"
M`````````$@"````````2`(````````@````````````````````!```````
M`````````````"$````'`````@````````!H`@```````&@"````````)```
M``````````````````0````````````````````X````!0````(`````````
MD`(```````"0`@```````"P#````````!@`````````(``````````0`````
M````-````/;__V\"`````````,`%````````P`4```````"\``````````8`
M````````"````````````````````#X````+`````@````````"`!@``````
M`(`&````````P`D````````'````!P````@`````````&`````````!&````
M`P````(`````````0!````````!`$````````,X$```````````````````!
M````````````````````3@```/___V\"``````````X5````````#A4`````
M``#0``````````8``````````@`````````"`````````%L```#^__]O`@``
M``````#@%0```````.`5````````<``````````'`````P````@`````````
M``````````!J````!`````(`````````4!8```````!0%@```````,@$````
M````!@`````````(`````````!@`````````=`````0```!"`````````!@;
M````````&!L```````"@!0````````8````5````"``````````8````````
M`'D````!````!@````````#`(````````,`@````````X`,`````````````
M`````!``````````$`````````!^`````0````8`````````H"0```````"@
M)````````)@^```````````````````(````````````````````A`````$`
M```"`````````#AC````````.&,```````!"0```````````````````"```
M`````````````````(P````!`````@````````!\HP```````'RC````````
MW`````````````````````0```````````````````":`````0````,`````
M````H/,```````"@LP```````!`*```````````````````(````````````
M````````I`````X````#`````````+#]````````L+T````````(````````
M````````````"``````````(`````````+`````/`````P````````"X_0``
M`````+B]````````"`````````````````````@`````````"`````````"\
M````!@````,`````````P/T```````#`O0```````$`"````````!P``````
M```(`````````!``````````Q0````$````#`````````````0```````,``
M``````!`````````````````````"````````````````````,L````!````
M`P````````!```$``````$#`````````>`(```````````````````@`````
M````"`````````#0`````0````,`````````N`(!``````"XP@````````@`
M```````````````````(````````````````````UP````@````#````````
M`,`"`0``````P,(````````P$```````````````````"```````````````
M`````-P````!````,````````````````````,#"````````*0``````````
M``````````$``````````0`````````!`````P``````````````````````
J``#IP@```````.4````````````````````!````````````````````
